import { a as we, b as Xt, g as ct, d as ve, c as Jt, e as Qt } from "./chunk-TZMSLE5B-DMjryRGF.js";
import { _ as f, n as Ie, c as st, d as St, l as Q, j as re, e as Le, f as _e, k as I, b as se, s as Ae, p as ke, a as Pe, g as Ne, q as Se, t as Me, J as Re, y as De, i as Mt, u as W, L as z, M as _t, N as ie, Z as Ce, O as Oe, P as ne, F as Ht } from "./mermaid.core-CMO0znjE.js";
import { I as Be } from "./chunk-QZHKN3VN-DfoHPLLU.js";
var Ut = (function() {
  var e = /* @__PURE__ */ f(function(pt, v, A, L) {
    for (A = A || {}, L = pt.length; L--; A[pt[L]] = v) ;
    return A;
  }, "o"), t = [1, 2], n = [1, 3], s = [1, 4], r = [2, 4], i = [1, 9], c = [1, 11], h = [1, 13], o = [1, 14], a = [1, 16], p = [1, 17], g = [1, 18], x = [1, 24], y = [1, 25], m = [1, 26], w = [1, 27], k = [1, 28], N = [1, 29], S = [1, 30], O = [1, 31], B = [1, 32], q = [1, 33], H = [1, 34], Z = [1, 35], at = [1, 36], U = [1, 37], G = [1, 38], F = [1, 39], D = [1, 41], $ = [1, 42], K = [1, 43], j = [1, 44], rt = [1, 45], R = [1, 46], E = [1, 4, 5, 13, 14, 16, 18, 21, 23, 29, 30, 31, 33, 35, 36, 37, 38, 39, 41, 43, 44, 46, 47, 48, 49, 50, 52, 53, 55, 60, 61, 62, 63, 71], _ = [2, 71], X = [4, 5, 16, 50, 52, 53], tt = [4, 5, 13, 14, 16, 18, 21, 23, 29, 30, 31, 33, 35, 36, 37, 38, 39, 41, 43, 44, 46, 50, 52, 53, 55, 60, 61, 62, 63, 71], M = [4, 5, 13, 14, 16, 18, 21, 23, 29, 30, 31, 33, 35, 36, 37, 38, 39, 41, 43, 44, 46, 49, 50, 52, 53, 55, 60, 61, 62, 63, 71], Vt = [4, 5, 13, 14, 16, 18, 21, 23, 29, 30, 31, 33, 35, 36, 37, 38, 39, 41, 43, 44, 46, 48, 50, 52, 53, 55, 60, 61, 62, 63, 71], Zt = [4, 5, 13, 14, 16, 18, 21, 23, 29, 30, 31, 33, 35, 36, 37, 38, 39, 41, 43, 44, 46, 47, 50, 52, 53, 55, 60, 61, 62, 63, 71], ot = [69, 70, 71], lt = [1, 127], Yt = {
    trace: /* @__PURE__ */ f(function() {
    }, "trace"),
    yy: {},
    symbols_: { error: 2, start: 3, SPACE: 4, NEWLINE: 5, SD: 6, document: 7, line: 8, statement: 9, box_section: 10, box_line: 11, participant_statement: 12, create: 13, box: 14, restOfLine: 15, end: 16, signal: 17, autonumber: 18, NUM: 19, off: 20, activate: 21, actor: 22, deactivate: 23, note_statement: 24, links_statement: 25, link_statement: 26, properties_statement: 27, details_statement: 28, title: 29, legacy_title: 30, acc_title: 31, acc_title_value: 32, acc_descr: 33, acc_descr_value: 34, acc_descr_multiline_value: 35, loop: 36, rect: 37, opt: 38, alt: 39, else_sections: 40, par: 41, par_sections: 42, par_over: 43, critical: 44, option_sections: 45, break: 46, option: 47, and: 48, else: 49, participant: 50, AS: 51, participant_actor: 52, destroy: 53, actor_with_config: 54, note: 55, placement: 56, text2: 57, over: 58, actor_pair: 59, links: 60, link: 61, properties: 62, details: 63, spaceList: 64, ",": 65, left_of: 66, right_of: 67, signaltype: 68, "+": 69, "-": 70, ACTOR: 71, config_object: 72, CONFIG_START: 73, CONFIG_CONTENT: 74, CONFIG_END: 75, SOLID_OPEN_ARROW: 76, DOTTED_OPEN_ARROW: 77, SOLID_ARROW: 78, BIDIRECTIONAL_SOLID_ARROW: 79, DOTTED_ARROW: 80, BIDIRECTIONAL_DOTTED_ARROW: 81, SOLID_CROSS: 82, DOTTED_CROSS: 83, SOLID_POINT: 84, DOTTED_POINT: 85, TXT: 86, $accept: 0, $end: 1 },
    terminals_: { 2: "error", 4: "SPACE", 5: "NEWLINE", 6: "SD", 13: "create", 14: "box", 15: "restOfLine", 16: "end", 18: "autonumber", 19: "NUM", 20: "off", 21: "activate", 23: "deactivate", 29: "title", 30: "legacy_title", 31: "acc_title", 32: "acc_title_value", 33: "acc_descr", 34: "acc_descr_value", 35: "acc_descr_multiline_value", 36: "loop", 37: "rect", 38: "opt", 39: "alt", 41: "par", 43: "par_over", 44: "critical", 46: "break", 47: "option", 48: "and", 49: "else", 50: "participant", 51: "AS", 52: "participant_actor", 53: "destroy", 55: "note", 58: "over", 60: "links", 61: "link", 62: "properties", 63: "details", 65: ",", 66: "left_of", 67: "right_of", 69: "+", 70: "-", 71: "ACTOR", 73: "CONFIG_START", 74: "CONFIG_CONTENT", 75: "CONFIG_END", 76: "SOLID_OPEN_ARROW", 77: "DOTTED_OPEN_ARROW", 78: "SOLID_ARROW", 79: "BIDIRECTIONAL_SOLID_ARROW", 80: "DOTTED_ARROW", 81: "BIDIRECTIONAL_DOTTED_ARROW", 82: "SOLID_CROSS", 83: "DOTTED_CROSS", 84: "SOLID_POINT", 85: "DOTTED_POINT", 86: "TXT" },
    productions_: [0, [3, 2], [3, 2], [3, 2], [7, 0], [7, 2], [8, 2], [8, 1], [8, 1], [10, 0], [10, 2], [11, 2], [11, 1], [11, 1], [9, 1], [9, 2], [9, 4], [9, 2], [9, 4], [9, 3], [9, 3], [9, 2], [9, 3], [9, 3], [9, 2], [9, 2], [9, 2], [9, 2], [9, 2], [9, 1], [9, 1], [9, 2], [9, 2], [9, 1], [9, 4], [9, 4], [9, 4], [9, 4], [9, 4], [9, 4], [9, 4], [9, 4], [45, 1], [45, 4], [42, 1], [42, 4], [40, 1], [40, 4], [12, 5], [12, 3], [12, 5], [12, 3], [12, 3], [12, 3], [24, 4], [24, 4], [25, 3], [26, 3], [27, 3], [28, 3], [64, 2], [64, 1], [59, 3], [59, 1], [56, 1], [56, 1], [17, 5], [17, 5], [17, 4], [54, 2], [72, 3], [22, 1], [68, 1], [68, 1], [68, 1], [68, 1], [68, 1], [68, 1], [68, 1], [68, 1], [68, 1], [68, 1], [57, 1]],
    performAction: /* @__PURE__ */ f(function(v, A, L, b, C, d, It) {
      var u = d.length - 1;
      switch (C) {
        case 3:
          return b.apply(d[u]), d[u];
        case 4:
        case 9:
          this.$ = [];
          break;
        case 5:
        case 10:
          d[u - 1].push(d[u]), this.$ = d[u - 1];
          break;
        case 6:
        case 7:
        case 11:
        case 12:
          this.$ = d[u];
          break;
        case 8:
        case 13:
          this.$ = [];
          break;
        case 15:
          d[u].type = "createParticipant", this.$ = d[u];
          break;
        case 16:
          d[u - 1].unshift({ type: "boxStart", boxData: b.parseBoxData(d[u - 2]) }), d[u - 1].push({ type: "boxEnd", boxText: d[u - 2] }), this.$ = d[u - 1];
          break;
        case 18:
          this.$ = { type: "sequenceIndex", sequenceIndex: Number(d[u - 2]), sequenceIndexStep: Number(d[u - 1]), sequenceVisible: !0, signalType: b.LINETYPE.AUTONUMBER };
          break;
        case 19:
          this.$ = { type: "sequenceIndex", sequenceIndex: Number(d[u - 1]), sequenceIndexStep: 1, sequenceVisible: !0, signalType: b.LINETYPE.AUTONUMBER };
          break;
        case 20:
          this.$ = { type: "sequenceIndex", sequenceVisible: !1, signalType: b.LINETYPE.AUTONUMBER };
          break;
        case 21:
          this.$ = { type: "sequenceIndex", sequenceVisible: !0, signalType: b.LINETYPE.AUTONUMBER };
          break;
        case 22:
          this.$ = { type: "activeStart", signalType: b.LINETYPE.ACTIVE_START, actor: d[u - 1].actor };
          break;
        case 23:
          this.$ = { type: "activeEnd", signalType: b.LINETYPE.ACTIVE_END, actor: d[u - 1].actor };
          break;
        case 29:
          b.setDiagramTitle(d[u].substring(6)), this.$ = d[u].substring(6);
          break;
        case 30:
          b.setDiagramTitle(d[u].substring(7)), this.$ = d[u].substring(7);
          break;
        case 31:
          this.$ = d[u].trim(), b.setAccTitle(this.$);
          break;
        case 32:
        case 33:
          this.$ = d[u].trim(), b.setAccDescription(this.$);
          break;
        case 34:
          d[u - 1].unshift({ type: "loopStart", loopText: b.parseMessage(d[u - 2]), signalType: b.LINETYPE.LOOP_START }), d[u - 1].push({ type: "loopEnd", loopText: d[u - 2], signalType: b.LINETYPE.LOOP_END }), this.$ = d[u - 1];
          break;
        case 35:
          d[u - 1].unshift({ type: "rectStart", color: b.parseMessage(d[u - 2]), signalType: b.LINETYPE.RECT_START }), d[u - 1].push({ type: "rectEnd", color: b.parseMessage(d[u - 2]), signalType: b.LINETYPE.RECT_END }), this.$ = d[u - 1];
          break;
        case 36:
          d[u - 1].unshift({ type: "optStart", optText: b.parseMessage(d[u - 2]), signalType: b.LINETYPE.OPT_START }), d[u - 1].push({ type: "optEnd", optText: b.parseMessage(d[u - 2]), signalType: b.LINETYPE.OPT_END }), this.$ = d[u - 1];
          break;
        case 37:
          d[u - 1].unshift({ type: "altStart", altText: b.parseMessage(d[u - 2]), signalType: b.LINETYPE.ALT_START }), d[u - 1].push({ type: "altEnd", signalType: b.LINETYPE.ALT_END }), this.$ = d[u - 1];
          break;
        case 38:
          d[u - 1].unshift({ type: "parStart", parText: b.parseMessage(d[u - 2]), signalType: b.LINETYPE.PAR_START }), d[u - 1].push({ type: "parEnd", signalType: b.LINETYPE.PAR_END }), this.$ = d[u - 1];
          break;
        case 39:
          d[u - 1].unshift({ type: "parStart", parText: b.parseMessage(d[u - 2]), signalType: b.LINETYPE.PAR_OVER_START }), d[u - 1].push({ type: "parEnd", signalType: b.LINETYPE.PAR_END }), this.$ = d[u - 1];
          break;
        case 40:
          d[u - 1].unshift({ type: "criticalStart", criticalText: b.parseMessage(d[u - 2]), signalType: b.LINETYPE.CRITICAL_START }), d[u - 1].push({ type: "criticalEnd", signalType: b.LINETYPE.CRITICAL_END }), this.$ = d[u - 1];
          break;
        case 41:
          d[u - 1].unshift({ type: "breakStart", breakText: b.parseMessage(d[u - 2]), signalType: b.LINETYPE.BREAK_START }), d[u - 1].push({ type: "breakEnd", optText: b.parseMessage(d[u - 2]), signalType: b.LINETYPE.BREAK_END }), this.$ = d[u - 1];
          break;
        case 43:
          this.$ = d[u - 3].concat([{ type: "option", optionText: b.parseMessage(d[u - 1]), signalType: b.LINETYPE.CRITICAL_OPTION }, d[u]]);
          break;
        case 45:
          this.$ = d[u - 3].concat([{ type: "and", parText: b.parseMessage(d[u - 1]), signalType: b.LINETYPE.PAR_AND }, d[u]]);
          break;
        case 47:
          this.$ = d[u - 3].concat([{ type: "else", altText: b.parseMessage(d[u - 1]), signalType: b.LINETYPE.ALT_ELSE }, d[u]]);
          break;
        case 48:
          d[u - 3].draw = "participant", d[u - 3].type = "addParticipant", d[u - 3].description = b.parseMessage(d[u - 1]), this.$ = d[u - 3];
          break;
        case 49:
          d[u - 1].draw = "participant", d[u - 1].type = "addParticipant", this.$ = d[u - 1];
          break;
        case 50:
          d[u - 3].draw = "actor", d[u - 3].type = "addParticipant", d[u - 3].description = b.parseMessage(d[u - 1]), this.$ = d[u - 3];
          break;
        case 51:
          d[u - 1].draw = "actor", d[u - 1].type = "addParticipant", this.$ = d[u - 1];
          break;
        case 52:
          d[u - 1].type = "destroyParticipant", this.$ = d[u - 1];
          break;
        case 53:
          d[u - 1].draw = "participant", d[u - 1].type = "addParticipant", this.$ = d[u - 1];
          break;
        case 54:
          this.$ = [d[u - 1], { type: "addNote", placement: d[u - 2], actor: d[u - 1].actor, text: d[u] }];
          break;
        case 55:
          d[u - 2] = [].concat(d[u - 1], d[u - 1]).slice(0, 2), d[u - 2][0] = d[u - 2][0].actor, d[u - 2][1] = d[u - 2][1].actor, this.$ = [d[u - 1], { type: "addNote", placement: b.PLACEMENT.OVER, actor: d[u - 2].slice(0, 2), text: d[u] }];
          break;
        case 56:
          this.$ = [d[u - 1], { type: "addLinks", actor: d[u - 1].actor, text: d[u] }];
          break;
        case 57:
          this.$ = [d[u - 1], { type: "addALink", actor: d[u - 1].actor, text: d[u] }];
          break;
        case 58:
          this.$ = [d[u - 1], { type: "addProperties", actor: d[u - 1].actor, text: d[u] }];
          break;
        case 59:
          this.$ = [d[u - 1], { type: "addDetails", actor: d[u - 1].actor, text: d[u] }];
          break;
        case 62:
          this.$ = [d[u - 2], d[u]];
          break;
        case 63:
          this.$ = d[u];
          break;
        case 64:
          this.$ = b.PLACEMENT.LEFTOF;
          break;
        case 65:
          this.$ = b.PLACEMENT.RIGHTOF;
          break;
        case 66:
          this.$ = [
            d[u - 4],
            d[u - 1],
            { type: "addMessage", from: d[u - 4].actor, to: d[u - 1].actor, signalType: d[u - 3], msg: d[u], activate: !0 },
            { type: "activeStart", signalType: b.LINETYPE.ACTIVE_START, actor: d[u - 1].actor }
          ];
          break;
        case 67:
          this.$ = [
            d[u - 4],
            d[u - 1],
            { type: "addMessage", from: d[u - 4].actor, to: d[u - 1].actor, signalType: d[u - 3], msg: d[u] },
            { type: "activeEnd", signalType: b.LINETYPE.ACTIVE_END, actor: d[u - 4].actor }
          ];
          break;
        case 68:
          this.$ = [d[u - 3], d[u - 1], { type: "addMessage", from: d[u - 3].actor, to: d[u - 1].actor, signalType: d[u - 2], msg: d[u] }];
          break;
        case 69:
          this.$ = {
            type: "addParticipant",
            actor: d[u - 1],
            config: d[u]
          };
          break;
        case 70:
          this.$ = d[u - 1].trim();
          break;
        case 71:
          this.$ = { type: "addParticipant", actor: d[u] };
          break;
        case 72:
          this.$ = b.LINETYPE.SOLID_OPEN;
          break;
        case 73:
          this.$ = b.LINETYPE.DOTTED_OPEN;
          break;
        case 74:
          this.$ = b.LINETYPE.SOLID;
          break;
        case 75:
          this.$ = b.LINETYPE.BIDIRECTIONAL_SOLID;
          break;
        case 76:
          this.$ = b.LINETYPE.DOTTED;
          break;
        case 77:
          this.$ = b.LINETYPE.BIDIRECTIONAL_DOTTED;
          break;
        case 78:
          this.$ = b.LINETYPE.SOLID_CROSS;
          break;
        case 79:
          this.$ = b.LINETYPE.DOTTED_CROSS;
          break;
        case 80:
          this.$ = b.LINETYPE.SOLID_POINT;
          break;
        case 81:
          this.$ = b.LINETYPE.DOTTED_POINT;
          break;
        case 82:
          this.$ = b.parseMessage(d[u].trim().substring(1));
          break;
      }
    }, "anonymous"),
    table: [{ 3: 1, 4: t, 5: n, 6: s }, { 1: [3] }, { 3: 5, 4: t, 5: n, 6: s }, { 3: 6, 4: t, 5: n, 6: s }, e([1, 4, 5, 13, 14, 18, 21, 23, 29, 30, 31, 33, 35, 36, 37, 38, 39, 41, 43, 44, 46, 50, 52, 53, 55, 60, 61, 62, 63, 71], r, { 7: 7 }), { 1: [2, 1] }, { 1: [2, 2] }, { 1: [2, 3], 4: i, 5: c, 8: 8, 9: 10, 12: 12, 13: h, 14: o, 17: 15, 18: a, 21: p, 22: 40, 23: g, 24: 19, 25: 20, 26: 21, 27: 22, 28: 23, 29: x, 30: y, 31: m, 33: w, 35: k, 36: N, 37: S, 38: O, 39: B, 41: q, 43: H, 44: Z, 46: at, 50: U, 52: G, 53: F, 55: D, 60: $, 61: K, 62: j, 63: rt, 71: R }, e(E, [2, 5]), { 9: 47, 12: 12, 13: h, 14: o, 17: 15, 18: a, 21: p, 22: 40, 23: g, 24: 19, 25: 20, 26: 21, 27: 22, 28: 23, 29: x, 30: y, 31: m, 33: w, 35: k, 36: N, 37: S, 38: O, 39: B, 41: q, 43: H, 44: Z, 46: at, 50: U, 52: G, 53: F, 55: D, 60: $, 61: K, 62: j, 63: rt, 71: R }, e(E, [2, 7]), e(E, [2, 8]), e(E, [2, 14]), { 12: 48, 50: U, 52: G, 53: F }, { 15: [1, 49] }, { 5: [1, 50] }, { 5: [1, 53], 19: [1, 51], 20: [1, 52] }, { 22: 54, 71: R }, { 22: 55, 71: R }, { 5: [1, 56] }, { 5: [1, 57] }, { 5: [1, 58] }, { 5: [1, 59] }, { 5: [1, 60] }, e(E, [2, 29]), e(E, [2, 30]), { 32: [1, 61] }, { 34: [1, 62] }, e(E, [2, 33]), { 15: [1, 63] }, { 15: [1, 64] }, { 15: [1, 65] }, { 15: [1, 66] }, { 15: [1, 67] }, { 15: [1, 68] }, { 15: [1, 69] }, { 15: [1, 70] }, { 22: 71, 54: 72, 71: [1, 73] }, { 22: 74, 71: R }, { 22: 75, 71: R }, { 68: 76, 76: [1, 77], 77: [1, 78], 78: [1, 79], 79: [1, 80], 80: [1, 81], 81: [1, 82], 82: [1, 83], 83: [1, 84], 84: [1, 85], 85: [1, 86] }, { 56: 87, 58: [1, 88], 66: [1, 89], 67: [1, 90] }, { 22: 91, 71: R }, { 22: 92, 71: R }, { 22: 93, 71: R }, { 22: 94, 71: R }, e([5, 51, 65, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86], _), e(E, [2, 6]), e(E, [2, 15]), e(X, [2, 9], { 10: 95 }), e(E, [2, 17]), { 5: [1, 97], 19: [1, 96] }, { 5: [1, 98] }, e(E, [2, 21]), { 5: [1, 99] }, { 5: [1, 100] }, e(E, [2, 24]), e(E, [2, 25]), e(E, [2, 26]), e(E, [2, 27]), e(E, [2, 28]), e(E, [2, 31]), e(E, [2, 32]), e(tt, r, { 7: 101 }), e(tt, r, { 7: 102 }), e(tt, r, { 7: 103 }), e(M, r, { 40: 104, 7: 105 }), e(Vt, r, { 42: 106, 7: 107 }), e(Vt, r, { 7: 107, 42: 108 }), e(Zt, r, { 45: 109, 7: 110 }), e(tt, r, { 7: 111 }), { 5: [1, 113], 51: [1, 112] }, { 5: [1, 114] }, e([5, 51], _, { 72: 115, 73: [1, 116] }), { 5: [1, 118], 51: [1, 117] }, { 5: [1, 119] }, { 22: 122, 69: [1, 120], 70: [1, 121], 71: R }, e(ot, [2, 72]), e(ot, [2, 73]), e(ot, [2, 74]), e(ot, [2, 75]), e(ot, [2, 76]), e(ot, [2, 77]), e(ot, [2, 78]), e(ot, [2, 79]), e(ot, [2, 80]), e(ot, [2, 81]), { 22: 123, 71: R }, { 22: 125, 59: 124, 71: R }, { 71: [2, 64] }, { 71: [2, 65] }, { 57: 126, 86: lt }, { 57: 128, 86: lt }, { 57: 129, 86: lt }, { 57: 130, 86: lt }, { 4: [1, 133], 5: [1, 135], 11: 132, 12: 134, 16: [1, 131], 50: U, 52: G, 53: F }, { 5: [1, 136] }, e(E, [2, 19]), e(E, [2, 20]), e(E, [2, 22]), e(E, [2, 23]), { 4: i, 5: c, 8: 8, 9: 10, 12: 12, 13: h, 14: o, 16: [1, 137], 17: 15, 18: a, 21: p, 22: 40, 23: g, 24: 19, 25: 20, 26: 21, 27: 22, 28: 23, 29: x, 30: y, 31: m, 33: w, 35: k, 36: N, 37: S, 38: O, 39: B, 41: q, 43: H, 44: Z, 46: at, 50: U, 52: G, 53: F, 55: D, 60: $, 61: K, 62: j, 63: rt, 71: R }, { 4: i, 5: c, 8: 8, 9: 10, 12: 12, 13: h, 14: o, 16: [1, 138], 17: 15, 18: a, 21: p, 22: 40, 23: g, 24: 19, 25: 20, 26: 21, 27: 22, 28: 23, 29: x, 30: y, 31: m, 33: w, 35: k, 36: N, 37: S, 38: O, 39: B, 41: q, 43: H, 44: Z, 46: at, 50: U, 52: G, 53: F, 55: D, 60: $, 61: K, 62: j, 63: rt, 71: R }, { 4: i, 5: c, 8: 8, 9: 10, 12: 12, 13: h, 14: o, 16: [1, 139], 17: 15, 18: a, 21: p, 22: 40, 23: g, 24: 19, 25: 20, 26: 21, 27: 22, 28: 23, 29: x, 30: y, 31: m, 33: w, 35: k, 36: N, 37: S, 38: O, 39: B, 41: q, 43: H, 44: Z, 46: at, 50: U, 52: G, 53: F, 55: D, 60: $, 61: K, 62: j, 63: rt, 71: R }, { 16: [1, 140] }, { 4: i, 5: c, 8: 8, 9: 10, 12: 12, 13: h, 14: o, 16: [2, 46], 17: 15, 18: a, 21: p, 22: 40, 23: g, 24: 19, 25: 20, 26: 21, 27: 22, 28: 23, 29: x, 30: y, 31: m, 33: w, 35: k, 36: N, 37: S, 38: O, 39: B, 41: q, 43: H, 44: Z, 46: at, 49: [1, 141], 50: U, 52: G, 53: F, 55: D, 60: $, 61: K, 62: j, 63: rt, 71: R }, { 16: [1, 142] }, { 4: i, 5: c, 8: 8, 9: 10, 12: 12, 13: h, 14: o, 16: [2, 44], 17: 15, 18: a, 21: p, 22: 40, 23: g, 24: 19, 25: 20, 26: 21, 27: 22, 28: 23, 29: x, 30: y, 31: m, 33: w, 35: k, 36: N, 37: S, 38: O, 39: B, 41: q, 43: H, 44: Z, 46: at, 48: [1, 143], 50: U, 52: G, 53: F, 55: D, 60: $, 61: K, 62: j, 63: rt, 71: R }, { 16: [1, 144] }, { 16: [1, 145] }, { 4: i, 5: c, 8: 8, 9: 10, 12: 12, 13: h, 14: o, 16: [2, 42], 17: 15, 18: a, 21: p, 22: 40, 23: g, 24: 19, 25: 20, 26: 21, 27: 22, 28: 23, 29: x, 30: y, 31: m, 33: w, 35: k, 36: N, 37: S, 38: O, 39: B, 41: q, 43: H, 44: Z, 46: at, 47: [1, 146], 50: U, 52: G, 53: F, 55: D, 60: $, 61: K, 62: j, 63: rt, 71: R }, { 4: i, 5: c, 8: 8, 9: 10, 12: 12, 13: h, 14: o, 16: [1, 147], 17: 15, 18: a, 21: p, 22: 40, 23: g, 24: 19, 25: 20, 26: 21, 27: 22, 28: 23, 29: x, 30: y, 31: m, 33: w, 35: k, 36: N, 37: S, 38: O, 39: B, 41: q, 43: H, 44: Z, 46: at, 50: U, 52: G, 53: F, 55: D, 60: $, 61: K, 62: j, 63: rt, 71: R }, { 15: [1, 148] }, e(E, [2, 49]), e(E, [2, 53]), { 5: [2, 69] }, { 74: [1, 149] }, { 15: [1, 150] }, e(E, [2, 51]), e(E, [2, 52]), { 22: 151, 71: R }, { 22: 152, 71: R }, { 57: 153, 86: lt }, { 57: 154, 86: lt }, { 57: 155, 86: lt }, { 65: [1, 156], 86: [2, 63] }, { 5: [2, 56] }, { 5: [2, 82] }, { 5: [2, 57] }, { 5: [2, 58] }, { 5: [2, 59] }, e(E, [2, 16]), e(X, [2, 10]), { 12: 157, 50: U, 52: G, 53: F }, e(X, [2, 12]), e(X, [2, 13]), e(E, [2, 18]), e(E, [2, 34]), e(E, [2, 35]), e(E, [2, 36]), e(E, [2, 37]), { 15: [1, 158] }, e(E, [2, 38]), { 15: [1, 159] }, e(E, [2, 39]), e(E, [2, 40]), { 15: [1, 160] }, e(E, [2, 41]), { 5: [1, 161] }, { 75: [1, 162] }, { 5: [1, 163] }, { 57: 164, 86: lt }, { 57: 165, 86: lt }, { 5: [2, 68] }, { 5: [2, 54] }, { 5: [2, 55] }, { 22: 166, 71: R }, e(X, [2, 11]), e(M, r, { 7: 105, 40: 167 }), e(Vt, r, { 7: 107, 42: 168 }), e(Zt, r, { 7: 110, 45: 169 }), e(E, [2, 48]), { 5: [2, 70] }, e(E, [2, 50]), { 5: [2, 66] }, { 5: [2, 67] }, { 86: [2, 62] }, { 16: [2, 47] }, { 16: [2, 45] }, { 16: [2, 43] }],
    defaultActions: { 5: [2, 1], 6: [2, 2], 89: [2, 64], 90: [2, 65], 115: [2, 69], 126: [2, 56], 127: [2, 82], 128: [2, 57], 129: [2, 58], 130: [2, 59], 153: [2, 68], 154: [2, 54], 155: [2, 55], 162: [2, 70], 164: [2, 66], 165: [2, 67], 166: [2, 62], 167: [2, 47], 168: [2, 45], 169: [2, 43] },
    parseError: /* @__PURE__ */ f(function(v, A) {
      if (A.recoverable)
        this.trace(v);
      else {
        var L = new Error(v);
        throw L.hash = A, L;
      }
    }, "parseError"),
    parse: /* @__PURE__ */ f(function(v) {
      var A = this, L = [0], b = [], C = [null], d = [], It = this.table, u = "", kt = 0, $t = 0, Te = 2, jt = 1, Ee = d.slice.call(arguments, 1), Y = Object.create(this.lexer), ft = { yy: {} };
      for (var Wt in this.yy)
        Object.prototype.hasOwnProperty.call(this.yy, Wt) && (ft.yy[Wt] = this.yy[Wt]);
      Y.setInput(v, ft.yy), ft.yy.lexer = Y, ft.yy.parser = this, typeof Y.yylloc > "u" && (Y.yylloc = {});
      var Ft = Y.yylloc;
      d.push(Ft);
      var be = Y.options && Y.options.ranges;
      typeof ft.yy.parseError == "function" ? this.parseError = ft.yy.parseError : this.parseError = Object.getPrototypeOf(this).parseError;
      function me(et) {
        L.length = L.length - 2 * et, C.length = C.length - et, d.length = d.length - et;
      }
      f(me, "popStack");
      function te() {
        var et;
        return et = b.pop() || Y.lex() || jt, typeof et != "number" && (et instanceof Array && (b = et, et = b.pop()), et = A.symbols_[et] || et), et;
      }
      f(te, "lex");
      for (var J, yt, it, qt, bt = {}, Pt, ht, ee, Nt; ; ) {
        if (yt = L[L.length - 1], this.defaultActions[yt] ? it = this.defaultActions[yt] : ((J === null || typeof J > "u") && (J = te()), it = It[yt] && It[yt][J]), typeof it > "u" || !it.length || !it[0]) {
          var zt = "";
          Nt = [];
          for (Pt in It[yt])
            this.terminals_[Pt] && Pt > Te && Nt.push("'" + this.terminals_[Pt] + "'");
          Y.showPosition ? zt = "Parse error on line " + (kt + 1) + `:
` + Y.showPosition() + `
Expecting ` + Nt.join(", ") + ", got '" + (this.terminals_[J] || J) + "'" : zt = "Parse error on line " + (kt + 1) + ": Unexpected " + (J == jt ? "end of input" : "'" + (this.terminals_[J] || J) + "'"), this.parseError(zt, {
            text: Y.match,
            token: this.terminals_[J] || J,
            line: Y.yylineno,
            loc: Ft,
            expected: Nt
          });
        }
        if (it[0] instanceof Array && it.length > 1)
          throw new Error("Parse Error: multiple actions possible at state: " + yt + ", token: " + J);
        switch (it[0]) {
          case 1:
            L.push(J), C.push(Y.yytext), d.push(Y.yylloc), L.push(it[1]), J = null, $t = Y.yyleng, u = Y.yytext, kt = Y.yylineno, Ft = Y.yylloc;
            break;
          case 2:
            if (ht = this.productions_[it[1]][1], bt.$ = C[C.length - ht], bt._$ = {
              first_line: d[d.length - (ht || 1)].first_line,
              last_line: d[d.length - 1].last_line,
              first_column: d[d.length - (ht || 1)].first_column,
              last_column: d[d.length - 1].last_column
            }, be && (bt._$.range = [
              d[d.length - (ht || 1)].range[0],
              d[d.length - 1].range[1]
            ]), qt = this.performAction.apply(bt, [
              u,
              $t,
              kt,
              ft.yy,
              it[1],
              C,
              d
            ].concat(Ee)), typeof qt < "u")
              return qt;
            ht && (L = L.slice(0, -1 * ht * 2), C = C.slice(0, -1 * ht), d = d.slice(0, -1 * ht)), L.push(this.productions_[it[1]][0]), C.push(bt.$), d.push(bt._$), ee = It[L[L.length - 2]][L[L.length - 1]], L.push(ee);
            break;
          case 3:
            return !0;
        }
      }
      return !0;
    }, "parse")
  }, ye = /* @__PURE__ */ (function() {
    var pt = {
      EOF: 1,
      parseError: /* @__PURE__ */ f(function(A, L) {
        if (this.yy.parser)
          this.yy.parser.parseError(A, L);
        else
          throw new Error(A);
      }, "parseError"),
      // resets the lexer, sets new input
      setInput: /* @__PURE__ */ f(function(v, A) {
        return this.yy = A || this.yy || {}, this._input = v, this._more = this._backtrack = this.done = !1, this.yylineno = this.yyleng = 0, this.yytext = this.matched = this.match = "", this.conditionStack = ["INITIAL"], this.yylloc = {
          first_line: 1,
          first_column: 0,
          last_line: 1,
          last_column: 0
        }, this.options.ranges && (this.yylloc.range = [0, 0]), this.offset = 0, this;
      }, "setInput"),
      // consumes and returns one char from the input
      input: /* @__PURE__ */ f(function() {
        var v = this._input[0];
        this.yytext += v, this.yyleng++, this.offset++, this.match += v, this.matched += v;
        var A = v.match(/(?:\r\n?|\n).*/g);
        return A ? (this.yylineno++, this.yylloc.last_line++) : this.yylloc.last_column++, this.options.ranges && this.yylloc.range[1]++, this._input = this._input.slice(1), v;
      }, "input"),
      // unshifts one char (or a string) into the input
      unput: /* @__PURE__ */ f(function(v) {
        var A = v.length, L = v.split(/(?:\r\n?|\n)/g);
        this._input = v + this._input, this.yytext = this.yytext.substr(0, this.yytext.length - A), this.offset -= A;
        var b = this.match.split(/(?:\r\n?|\n)/g);
        this.match = this.match.substr(0, this.match.length - 1), this.matched = this.matched.substr(0, this.matched.length - 1), L.length - 1 && (this.yylineno -= L.length - 1);
        var C = this.yylloc.range;
        return this.yylloc = {
          first_line: this.yylloc.first_line,
          last_line: this.yylineno + 1,
          first_column: this.yylloc.first_column,
          last_column: L ? (L.length === b.length ? this.yylloc.first_column : 0) + b[b.length - L.length].length - L[0].length : this.yylloc.first_column - A
        }, this.options.ranges && (this.yylloc.range = [C[0], C[0] + this.yyleng - A]), this.yyleng = this.yytext.length, this;
      }, "unput"),
      // When called from action, caches matched text and appends it on next action
      more: /* @__PURE__ */ f(function() {
        return this._more = !0, this;
      }, "more"),
      // When called from action, signals the lexer that this rule fails to match the input, so the next matching rule (regex) should be tested instead.
      reject: /* @__PURE__ */ f(function() {
        if (this.options.backtrack_lexer)
          this._backtrack = !0;
        else
          return this.parseError("Lexical error on line " + (this.yylineno + 1) + `. You can only invoke reject() in the lexer when the lexer is of the backtracking persuasion (options.backtrack_lexer = true).
` + this.showPosition(), {
            text: "",
            token: null,
            line: this.yylineno
          });
        return this;
      }, "reject"),
      // retain first n characters of the match
      less: /* @__PURE__ */ f(function(v) {
        this.unput(this.match.slice(v));
      }, "less"),
      // displays already matched input, i.e. for error messages
      pastInput: /* @__PURE__ */ f(function() {
        var v = this.matched.substr(0, this.matched.length - this.match.length);
        return (v.length > 20 ? "..." : "") + v.substr(-20).replace(/\n/g, "");
      }, "pastInput"),
      // displays upcoming input, i.e. for error messages
      upcomingInput: /* @__PURE__ */ f(function() {
        var v = this.match;
        return v.length < 20 && (v += this._input.substr(0, 20 - v.length)), (v.substr(0, 20) + (v.length > 20 ? "..." : "")).replace(/\n/g, "");
      }, "upcomingInput"),
      // displays the character position where the lexing error occurred, i.e. for error messages
      showPosition: /* @__PURE__ */ f(function() {
        var v = this.pastInput(), A = new Array(v.length + 1).join("-");
        return v + this.upcomingInput() + `
` + A + "^";
      }, "showPosition"),
      // test the lexed token: return FALSE when not a match, otherwise return token
      test_match: /* @__PURE__ */ f(function(v, A) {
        var L, b, C;
        if (this.options.backtrack_lexer && (C = {
          yylineno: this.yylineno,
          yylloc: {
            first_line: this.yylloc.first_line,
            last_line: this.last_line,
            first_column: this.yylloc.first_column,
            last_column: this.yylloc.last_column
          },
          yytext: this.yytext,
          match: this.match,
          matches: this.matches,
          matched: this.matched,
          yyleng: this.yyleng,
          offset: this.offset,
          _more: this._more,
          _input: this._input,
          yy: this.yy,
          conditionStack: this.conditionStack.slice(0),
          done: this.done
        }, this.options.ranges && (C.yylloc.range = this.yylloc.range.slice(0))), b = v[0].match(/(?:\r\n?|\n).*/g), b && (this.yylineno += b.length), this.yylloc = {
          first_line: this.yylloc.last_line,
          last_line: this.yylineno + 1,
          first_column: this.yylloc.last_column,
          last_column: b ? b[b.length - 1].length - b[b.length - 1].match(/\r?\n?/)[0].length : this.yylloc.last_column + v[0].length
        }, this.yytext += v[0], this.match += v[0], this.matches = v, this.yyleng = this.yytext.length, this.options.ranges && (this.yylloc.range = [this.offset, this.offset += this.yyleng]), this._more = !1, this._backtrack = !1, this._input = this._input.slice(v[0].length), this.matched += v[0], L = this.performAction.call(this, this.yy, this, A, this.conditionStack[this.conditionStack.length - 1]), this.done && this._input && (this.done = !1), L)
          return L;
        if (this._backtrack) {
          for (var d in C)
            this[d] = C[d];
          return !1;
        }
        return !1;
      }, "test_match"),
      // return next match in input
      next: /* @__PURE__ */ f(function() {
        if (this.done)
          return this.EOF;
        this._input || (this.done = !0);
        var v, A, L, b;
        this._more || (this.yytext = "", this.match = "");
        for (var C = this._currentRules(), d = 0; d < C.length; d++)
          if (L = this._input.match(this.rules[C[d]]), L && (!A || L[0].length > A[0].length)) {
            if (A = L, b = d, this.options.backtrack_lexer) {
              if (v = this.test_match(L, C[d]), v !== !1)
                return v;
              if (this._backtrack) {
                A = !1;
                continue;
              } else
                return !1;
            } else if (!this.options.flex)
              break;
          }
        return A ? (v = this.test_match(A, C[b]), v !== !1 ? v : !1) : this._input === "" ? this.EOF : this.parseError("Lexical error on line " + (this.yylineno + 1) + `. Unrecognized text.
` + this.showPosition(), {
          text: "",
          token: null,
          line: this.yylineno
        });
      }, "next"),
      // return next match that has a token
      lex: /* @__PURE__ */ f(function() {
        var A = this.next();
        return A || this.lex();
      }, "lex"),
      // activates a new lexer condition state (pushes the new lexer condition state onto the condition stack)
      begin: /* @__PURE__ */ f(function(A) {
        this.conditionStack.push(A);
      }, "begin"),
      // pop the previously active lexer condition state off the condition stack
      popState: /* @__PURE__ */ f(function() {
        var A = this.conditionStack.length - 1;
        return A > 0 ? this.conditionStack.pop() : this.conditionStack[0];
      }, "popState"),
      // produce the lexer rule set which is active for the currently active lexer condition state
      _currentRules: /* @__PURE__ */ f(function() {
        return this.conditionStack.length && this.conditionStack[this.conditionStack.length - 1] ? this.conditions[this.conditionStack[this.conditionStack.length - 1]].rules : this.conditions.INITIAL.rules;
      }, "_currentRules"),
      // return the currently active lexer condition state; when an index argument is provided it produces the N-th previous condition state, if available
      topState: /* @__PURE__ */ f(function(A) {
        return A = this.conditionStack.length - 1 - Math.abs(A || 0), A >= 0 ? this.conditionStack[A] : "INITIAL";
      }, "topState"),
      // alias for begin(condition)
      pushState: /* @__PURE__ */ f(function(A) {
        this.begin(A);
      }, "pushState"),
      // return the number of states currently on the stack
      stateStackSize: /* @__PURE__ */ f(function() {
        return this.conditionStack.length;
      }, "stateStackSize"),
      options: { "case-insensitive": !0 },
      performAction: /* @__PURE__ */ f(function(A, L, b, C) {
        switch (b) {
          case 0:
            return 5;
          case 1:
            break;
          case 2:
            break;
          case 3:
            break;
          case 4:
            break;
          case 5:
            break;
          case 6:
            return 19;
          case 7:
            return this.begin("CONFIG"), 73;
          case 8:
            return 74;
          case 9:
            return this.popState(), this.popState(), 75;
          case 10:
            return L.yytext = L.yytext.trim(), 71;
          case 11:
            return L.yytext = L.yytext.trim(), this.begin("ALIAS"), 71;
          case 12:
            return this.begin("LINE"), 14;
          case 13:
            return this.begin("ID"), 50;
          case 14:
            return this.begin("ID"), 52;
          case 15:
            return 13;
          case 16:
            return this.begin("ID"), 53;
          case 17:
            return L.yytext = L.yytext.trim(), this.begin("ALIAS"), 71;
          case 18:
            return this.popState(), this.popState(), this.begin("LINE"), 51;
          case 19:
            return this.popState(), this.popState(), 5;
          case 20:
            return this.begin("LINE"), 36;
          case 21:
            return this.begin("LINE"), 37;
          case 22:
            return this.begin("LINE"), 38;
          case 23:
            return this.begin("LINE"), 39;
          case 24:
            return this.begin("LINE"), 49;
          case 25:
            return this.begin("LINE"), 41;
          case 26:
            return this.begin("LINE"), 43;
          case 27:
            return this.begin("LINE"), 48;
          case 28:
            return this.begin("LINE"), 44;
          case 29:
            return this.begin("LINE"), 47;
          case 30:
            return this.begin("LINE"), 46;
          case 31:
            return this.popState(), 15;
          case 32:
            return 16;
          case 33:
            return 66;
          case 34:
            return 67;
          case 35:
            return 60;
          case 36:
            return 61;
          case 37:
            return 62;
          case 38:
            return 63;
          case 39:
            return 58;
          case 40:
            return 55;
          case 41:
            return this.begin("ID"), 21;
          case 42:
            return this.begin("ID"), 23;
          case 43:
            return 29;
          case 44:
            return 30;
          case 45:
            return this.begin("acc_title"), 31;
          case 46:
            return this.popState(), "acc_title_value";
          case 47:
            return this.begin("acc_descr"), 33;
          case 48:
            return this.popState(), "acc_descr_value";
          case 49:
            this.begin("acc_descr_multiline");
            break;
          case 50:
            this.popState();
            break;
          case 51:
            return "acc_descr_multiline_value";
          case 52:
            return 6;
          case 53:
            return 18;
          case 54:
            return 20;
          case 55:
            return 65;
          case 56:
            return 5;
          case 57:
            return L.yytext = L.yytext.trim(), 71;
          case 58:
            return 78;
          case 59:
            return 79;
          case 60:
            return 80;
          case 61:
            return 81;
          case 62:
            return 76;
          case 63:
            return 77;
          case 64:
            return 82;
          case 65:
            return 83;
          case 66:
            return 84;
          case 67:
            return 85;
          case 68:
            return 86;
          case 69:
            return 86;
          case 70:
            return 69;
          case 71:
            return 70;
          case 72:
            return 5;
          case 73:
            return "INVALID";
        }
      }, "anonymous"),
      rules: [/^(?:[\n]+)/i, /^(?:\s+)/i, /^(?:((?!\n)\s)+)/i, /^(?:#[^\n]*)/i, /^(?:%(?!\{)[^\n]*)/i, /^(?:[^\}]%%[^\n]*)/i, /^(?:[0-9]+(?=[ \n]+))/i, /^(?:@\{)/i, /^(?:[^\}]+)/i, /^(?:\})/i, /^(?:[^\<->\->:\n,;@\s]+(?=@\{))/i, /^(?:[^\<->\->:\n,;@]+?([\-]*[^\<->\->:\n,;@]+?)*?(?=((?!\n)\s)+as(?!\n)\s|[#\n;]|$))/i, /^(?:box\b)/i, /^(?:participant\b)/i, /^(?:actor\b)/i, /^(?:create\b)/i, /^(?:destroy\b)/i, /^(?:[^<\->\->:\n,;]+?([\-]*[^<\->\->:\n,;]+?)*?(?=((?!\n)\s)+as(?!\n)\s|[#\n;]|$))/i, /^(?:as\b)/i, /^(?:(?:))/i, /^(?:loop\b)/i, /^(?:rect\b)/i, /^(?:opt\b)/i, /^(?:alt\b)/i, /^(?:else\b)/i, /^(?:par\b)/i, /^(?:par_over\b)/i, /^(?:and\b)/i, /^(?:critical\b)/i, /^(?:option\b)/i, /^(?:break\b)/i, /^(?:(?:[:]?(?:no)?wrap)?[^#\n;]*)/i, /^(?:end\b)/i, /^(?:left of\b)/i, /^(?:right of\b)/i, /^(?:links\b)/i, /^(?:link\b)/i, /^(?:properties\b)/i, /^(?:details\b)/i, /^(?:over\b)/i, /^(?:note\b)/i, /^(?:activate\b)/i, /^(?:deactivate\b)/i, /^(?:title\s[^#\n;]+)/i, /^(?:title:\s[^#\n;]+)/i, /^(?:accTitle\s*:\s*)/i, /^(?:(?!\n||)*[^\n]*)/i, /^(?:accDescr\s*:\s*)/i, /^(?:(?!\n||)*[^\n]*)/i, /^(?:accDescr\s*\{\s*)/i, /^(?:[\}])/i, /^(?:[^\}]*)/i, /^(?:sequenceDiagram\b)/i, /^(?:autonumber\b)/i, /^(?:off\b)/i, /^(?:,)/i, /^(?:;)/i, /^(?:[^+<\->\->:\n,;]+((?!(-x|--x|-\)|--\)))[\-]*[^\+<\->\->:\n,;]+)*)/i, /^(?:->>)/i, /^(?:<<->>)/i, /^(?:-->>)/i, /^(?:<<-->>)/i, /^(?:->)/i, /^(?:-->)/i, /^(?:-[x])/i, /^(?:--[x])/i, /^(?:-[\)])/i, /^(?:--[\)])/i, /^(?::(?:(?:no)?wrap)?[^#\n;]*)/i, /^(?::)/i, /^(?:\+)/i, /^(?:-)/i, /^(?:$)/i, /^(?:.)/i],
      conditions: { acc_descr_multiline: { rules: [50, 51], inclusive: !1 }, acc_descr: { rules: [48], inclusive: !1 }, acc_title: { rules: [46], inclusive: !1 }, ID: { rules: [2, 3, 7, 10, 11, 17], inclusive: !1 }, ALIAS: { rules: [2, 3, 18, 19], inclusive: !1 }, LINE: { rules: [2, 3, 31], inclusive: !1 }, CONFIG: { rules: [8, 9], inclusive: !1 }, CONFIG_DATA: { rules: [], inclusive: !1 }, INITIAL: { rules: [0, 1, 3, 4, 5, 6, 12, 13, 14, 15, 16, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 47, 49, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73], inclusive: !0 } }
    };
    return pt;
  })();
  Yt.lexer = ye;
  function At() {
    this.yy = {};
  }
  return f(At, "Parser"), At.prototype = Yt, Yt.Parser = At, new At();
})();
Ut.parser = Ut;
var Ve = Ut, Ye = {
  SOLID: 0,
  DOTTED: 1,
  NOTE: 2,
  SOLID_CROSS: 3,
  DOTTED_CROSS: 4,
  SOLID_OPEN: 5,
  DOTTED_OPEN: 6,
  LOOP_START: 10,
  LOOP_END: 11,
  ALT_START: 12,
  ALT_ELSE: 13,
  ALT_END: 14,
  OPT_START: 15,
  OPT_END: 16,
  ACTIVE_START: 17,
  ACTIVE_END: 18,
  PAR_START: 19,
  PAR_AND: 20,
  PAR_END: 21,
  RECT_START: 22,
  RECT_END: 23,
  SOLID_POINT: 24,
  DOTTED_POINT: 25,
  AUTONUMBER: 26,
  CRITICAL_START: 27,
  CRITICAL_OPTION: 28,
  CRITICAL_END: 29,
  BREAK_START: 30,
  BREAK_END: 31,
  PAR_OVER_START: 32,
  BIDIRECTIONAL_SOLID: 33,
  BIDIRECTIONAL_DOTTED: 34
}, We = {
  FILLED: 0,
  OPEN: 1
}, Fe = {
  LEFTOF: 0,
  RIGHTOF: 1,
  OVER: 2
}, Rt = {
  ACTOR: "actor",
  CONTROL: "control",
  DATABASE: "database",
  ENTITY: "entity"
}, wt, qe = (wt = class {
  constructor() {
    this.state = new Be(() => ({
      prevActor: void 0,
      actors: /* @__PURE__ */ new Map(),
      createdActors: /* @__PURE__ */ new Map(),
      destroyedActors: /* @__PURE__ */ new Map(),
      boxes: [],
      messages: [],
      notes: [],
      sequenceNumbersEnabled: !1,
      wrapEnabled: void 0,
      currentBox: void 0,
      lastCreated: void 0,
      lastDestroyed: void 0
    })), this.setAccTitle = se, this.setAccDescription = Ae, this.setDiagramTitle = ke, this.getAccTitle = Pe, this.getAccDescription = Ne, this.getDiagramTitle = Se, this.apply = this.apply.bind(this), this.parseBoxData = this.parseBoxData.bind(this), this.parseMessage = this.parseMessage.bind(this), this.clear(), this.setWrap(st().wrap), this.LINETYPE = Ye, this.ARROWTYPE = We, this.PLACEMENT = Fe;
  }
  addBox(t) {
    this.state.records.boxes.push({
      name: t.text,
      wrap: t.wrap ?? this.autoWrap(),
      fill: t.color,
      actorKeys: []
    }), this.state.records.currentBox = this.state.records.boxes.slice(-1)[0];
  }
  addActor(t, n, s, r, i) {
    let c = this.state.records.currentBox, h;
    if (i !== void 0) {
      let a;
      i.includes(`
`) ? a = i + `
` : a = `{
` + i + `
}`, h = Me(a, { schema: Re });
    }
    r = h?.type ?? r;
    const o = this.state.records.actors.get(t);
    if (o) {
      if (this.state.records.currentBox && o.box && this.state.records.currentBox !== o.box)
        throw new Error(
          `A same participant should only be defined in one Box: ${o.name} can't be in '${o.box.name}' and in '${this.state.records.currentBox.name}' at the same time.`
        );
      if (c = o.box ? o.box : this.state.records.currentBox, o.box = c, o && n === o.name && s == null)
        return;
    }
    if (s?.text == null && (s = { text: n, type: r }), (r == null || s.text == null) && (s = { text: n, type: r }), this.state.records.actors.set(t, {
      box: c,
      name: n,
      description: s.text,
      wrap: s.wrap ?? this.autoWrap(),
      prevActor: this.state.records.prevActor,
      links: {},
      properties: {},
      actorCnt: null,
      rectData: null,
      type: r ?? "participant"
    }), this.state.records.prevActor) {
      const a = this.state.records.actors.get(this.state.records.prevActor);
      a && (a.nextActor = t);
    }
    this.state.records.currentBox && this.state.records.currentBox.actorKeys.push(t), this.state.records.prevActor = t;
  }
  activationCount(t) {
    let n, s = 0;
    if (!t)
      return 0;
    for (n = 0; n < this.state.records.messages.length; n++)
      this.state.records.messages[n].type === this.LINETYPE.ACTIVE_START && this.state.records.messages[n].from === t && s++, this.state.records.messages[n].type === this.LINETYPE.ACTIVE_END && this.state.records.messages[n].from === t && s--;
    return s;
  }
  addMessage(t, n, s, r) {
    this.state.records.messages.push({
      id: this.state.records.messages.length.toString(),
      from: t,
      to: n,
      message: s.text,
      wrap: s.wrap ?? this.autoWrap(),
      answer: r
    });
  }
  addSignal(t, n, s, r, i = !1) {
    if (r === this.LINETYPE.ACTIVE_END && this.activationCount(t ?? "") < 1) {
      const h = new Error("Trying to inactivate an inactive participant (" + t + ")");
      throw h.hash = {
        text: "->>-",
        token: "->>-",
        line: "1",
        loc: { first_line: 1, last_line: 1, first_column: 1, last_column: 1 },
        expected: ["'ACTIVE_PARTICIPANT'"]
      }, h;
    }
    return this.state.records.messages.push({
      id: this.state.records.messages.length.toString(),
      from: t,
      to: n,
      message: s?.text ?? "",
      wrap: s?.wrap ?? this.autoWrap(),
      type: r,
      activate: i
    }), !0;
  }
  hasAtLeastOneBox() {
    return this.state.records.boxes.length > 0;
  }
  hasAtLeastOneBoxWithTitle() {
    return this.state.records.boxes.some((t) => t.name);
  }
  getMessages() {
    return this.state.records.messages;
  }
  getBoxes() {
    return this.state.records.boxes;
  }
  getActors() {
    return this.state.records.actors;
  }
  getCreatedActors() {
    return this.state.records.createdActors;
  }
  getDestroyedActors() {
    return this.state.records.destroyedActors;
  }
  getActor(t) {
    return this.state.records.actors.get(t);
  }
  getActorKeys() {
    return [...this.state.records.actors.keys()];
  }
  enableSequenceNumbers() {
    this.state.records.sequenceNumbersEnabled = !0;
  }
  disableSequenceNumbers() {
    this.state.records.sequenceNumbersEnabled = !1;
  }
  showSequenceNumbers() {
    return this.state.records.sequenceNumbersEnabled;
  }
  setWrap(t) {
    this.state.records.wrapEnabled = t;
  }
  extractWrap(t) {
    if (t === void 0)
      return {};
    t = t.trim();
    const n = /^:?wrap:/.exec(t) !== null ? !0 : /^:?nowrap:/.exec(t) !== null ? !1 : void 0;
    return { cleanedText: (n === void 0 ? t : t.replace(/^:?(?:no)?wrap:/, "")).trim(), wrap: n };
  }
  autoWrap() {
    return this.state.records.wrapEnabled !== void 0 ? this.state.records.wrapEnabled : st().sequence?.wrap ?? !1;
  }
  clear() {
    this.state.reset(), De();
  }
  parseMessage(t) {
    const n = t.trim(), { wrap: s, cleanedText: r } = this.extractWrap(n), i = {
      text: r,
      wrap: s
    };
    return Q.debug(`parseMessage: ${JSON.stringify(i)}`), i;
  }
  // We expect the box statement to be color first then description
  // The color can be rgb,rgba,hsl,hsla, or css code names  #hex codes are not supported for now because of the way the char # is handled
  // We extract first segment as color, the rest of the line is considered as text
  parseBoxData(t) {
    const n = /^((?:rgba?|hsla?)\s*\(.*\)|\w*)(.*)$/.exec(t);
    let s = n?.[1] ? n[1].trim() : "transparent", r = n?.[2] ? n[2].trim() : void 0;
    if (window?.CSS)
      window.CSS.supports("color", s) || (s = "transparent", r = t.trim());
    else {
      const h = new Option().style;
      h.color = s, h.color !== s && (s = "transparent", r = t.trim());
    }
    const { wrap: i, cleanedText: c } = this.extractWrap(r);
    return {
      text: c ? Mt(c, st()) : void 0,
      color: s,
      wrap: i
    };
  }
  addNote(t, n, s) {
    const r = {
      actor: t,
      placement: n,
      message: s.text,
      wrap: s.wrap ?? this.autoWrap()
    }, i = [].concat(t, t);
    this.state.records.notes.push(r), this.state.records.messages.push({
      id: this.state.records.messages.length.toString(),
      from: i[0],
      to: i[1],
      message: s.text,
      wrap: s.wrap ?? this.autoWrap(),
      type: this.LINETYPE.NOTE,
      placement: n
    });
  }
  addLinks(t, n) {
    const s = this.getActor(t);
    try {
      let r = Mt(n.text, st());
      r = r.replace(/&equals;/g, "="), r = r.replace(/&amp;/g, "&");
      const i = JSON.parse(r);
      this.insertLinks(s, i);
    } catch (r) {
      Q.error("error while parsing actor link text", r);
    }
  }
  addALink(t, n) {
    const s = this.getActor(t);
    try {
      const r = {};
      let i = Mt(n.text, st());
      const c = i.indexOf("@");
      i = i.replace(/&equals;/g, "="), i = i.replace(/&amp;/g, "&");
      const h = i.slice(0, c - 1).trim(), o = i.slice(c + 1).trim();
      r[h] = o, this.insertLinks(s, r);
    } catch (r) {
      Q.error("error while parsing actor link text", r);
    }
  }
  insertLinks(t, n) {
    if (t.links == null)
      t.links = n;
    else
      for (const s in n)
        t.links[s] = n[s];
  }
  addProperties(t, n) {
    const s = this.getActor(t);
    try {
      const r = Mt(n.text, st()), i = JSON.parse(r);
      this.insertProperties(s, i);
    } catch (r) {
      Q.error("error while parsing actor properties text", r);
    }
  }
  insertProperties(t, n) {
    if (t.properties == null)
      t.properties = n;
    else
      for (const s in n)
        t.properties[s] = n[s];
  }
  boxEnd() {
    this.state.records.currentBox = void 0;
  }
  addDetails(t, n) {
    const s = this.getActor(t), r = document.getElementById(n.text);
    try {
      const i = r.innerHTML, c = JSON.parse(i);
      c.properties && this.insertProperties(s, c.properties), c.links && this.insertLinks(s, c.links);
    } catch (i) {
      Q.error("error while parsing actor details text", i);
    }
  }
  getActorProperty(t, n) {
    if (t?.properties !== void 0)
      return t.properties[n];
  }
  // eslint-disable-next-line @typescript-eslint/no-explicit-any, @typescript-eslint/no-redundant-type-constituents
  apply(t) {
    if (Array.isArray(t))
      t.forEach((n) => {
        this.apply(n);
      });
    else
      switch (t.type) {
        case "sequenceIndex":
          this.state.records.messages.push({
            id: this.state.records.messages.length.toString(),
            from: void 0,
            to: void 0,
            message: {
              start: t.sequenceIndex,
              step: t.sequenceIndexStep,
              visible: t.sequenceVisible
            },
            wrap: !1,
            type: t.signalType
          });
          break;
        case "addParticipant":
          this.addActor(t.actor, t.actor, t.description, t.draw, t.config);
          break;
        case "createParticipant":
          if (this.state.records.actors.has(t.actor))
            throw new Error(
              "It is not possible to have actors with the same id, even if one is destroyed before the next is created. Use 'AS' aliases to simulate the behavior"
            );
          this.state.records.lastCreated = t.actor, this.addActor(t.actor, t.actor, t.description, t.draw, t.config), this.state.records.createdActors.set(t.actor, this.state.records.messages.length);
          break;
        case "destroyParticipant":
          this.state.records.lastDestroyed = t.actor, this.state.records.destroyedActors.set(t.actor, this.state.records.messages.length);
          break;
        case "activeStart":
          this.addSignal(t.actor, void 0, void 0, t.signalType);
          break;
        case "activeEnd":
          this.addSignal(t.actor, void 0, void 0, t.signalType);
          break;
        case "addNote":
          this.addNote(t.actor, t.placement, t.text);
          break;
        case "addLinks":
          this.addLinks(t.actor, t.text);
          break;
        case "addALink":
          this.addALink(t.actor, t.text);
          break;
        case "addProperties":
          this.addProperties(t.actor, t.text);
          break;
        case "addDetails":
          this.addDetails(t.actor, t.text);
          break;
        case "addMessage":
          if (this.state.records.lastCreated) {
            if (t.to !== this.state.records.lastCreated)
              throw new Error(
                "The created participant " + this.state.records.lastCreated.name + " does not have an associated creating message after its declaration. Please check the sequence diagram."
              );
            this.state.records.lastCreated = void 0;
          } else if (this.state.records.lastDestroyed) {
            if (t.to !== this.state.records.lastDestroyed && t.from !== this.state.records.lastDestroyed)
              throw new Error(
                "The destroyed participant " + this.state.records.lastDestroyed.name + " does not have an associated destroying message after its declaration. Please check the sequence diagram."
              );
            this.state.records.lastDestroyed = void 0;
          }
          this.addSignal(t.from, t.to, t.msg, t.signalType, t.activate);
          break;
        case "boxStart":
          this.addBox(t.boxData);
          break;
        case "boxEnd":
          this.boxEnd();
          break;
        case "loopStart":
          this.addSignal(void 0, void 0, t.loopText, t.signalType);
          break;
        case "loopEnd":
          this.addSignal(void 0, void 0, void 0, t.signalType);
          break;
        case "rectStart":
          this.addSignal(void 0, void 0, t.color, t.signalType);
          break;
        case "rectEnd":
          this.addSignal(void 0, void 0, void 0, t.signalType);
          break;
        case "optStart":
          this.addSignal(void 0, void 0, t.optText, t.signalType);
          break;
        case "optEnd":
          this.addSignal(void 0, void 0, void 0, t.signalType);
          break;
        case "altStart":
          this.addSignal(void 0, void 0, t.altText, t.signalType);
          break;
        case "else":
          this.addSignal(void 0, void 0, t.altText, t.signalType);
          break;
        case "altEnd":
          this.addSignal(void 0, void 0, void 0, t.signalType);
          break;
        case "setAccTitle":
          se(t.text);
          break;
        case "parStart":
          this.addSignal(void 0, void 0, t.parText, t.signalType);
          break;
        case "and":
          this.addSignal(void 0, void 0, t.parText, t.signalType);
          break;
        case "parEnd":
          this.addSignal(void 0, void 0, void 0, t.signalType);
          break;
        case "criticalStart":
          this.addSignal(void 0, void 0, t.criticalText, t.signalType);
          break;
        case "option":
          this.addSignal(void 0, void 0, t.optionText, t.signalType);
          break;
        case "criticalEnd":
          this.addSignal(void 0, void 0, void 0, t.signalType);
          break;
        case "breakStart":
          this.addSignal(void 0, void 0, t.breakText, t.signalType);
          break;
        case "breakEnd":
          this.addSignal(void 0, void 0, void 0, t.signalType);
          break;
      }
  }
  getConfig() {
    return st().sequence;
  }
}, f(wt, "SequenceDB"), wt), ze = /* @__PURE__ */ f((e) => `.actor {
    stroke: ${e.actorBorder};
    fill: ${e.actorBkg};
  }

  text.actor > tspan {
    fill: ${e.actorTextColor};
    stroke: none;
  }

  .actor-line {
    stroke: ${e.actorLineColor};
  }
  
  .innerArc {
    stroke-width: 1.5;
    stroke-dasharray: none;
  }

  .messageLine0 {
    stroke-width: 1.5;
    stroke-dasharray: none;
    stroke: ${e.signalColor};
  }

  .messageLine1 {
    stroke-width: 1.5;
    stroke-dasharray: 2, 2;
    stroke: ${e.signalColor};
  }

  #arrowhead path {
    fill: ${e.signalColor};
    stroke: ${e.signalColor};
  }

  .sequenceNumber {
    fill: ${e.sequenceNumberColor};
  }

  #sequencenumber {
    fill: ${e.signalColor};
  }

  #crosshead path {
    fill: ${e.signalColor};
    stroke: ${e.signalColor};
  }

  .messageText {
    fill: ${e.signalTextColor};
    stroke: none;
  }

  .labelBox {
    stroke: ${e.labelBoxBorderColor};
    fill: ${e.labelBoxBkgColor};
  }

  .labelText, .labelText > tspan {
    fill: ${e.labelTextColor};
    stroke: none;
  }

  .loopText, .loopText > tspan {
    fill: ${e.loopTextColor};
    stroke: none;
  }

  .loopLine {
    stroke-width: 2px;
    stroke-dasharray: 2, 2;
    stroke: ${e.labelBoxBorderColor};
    fill: ${e.labelBoxBorderColor};
  }

  .note {
    //stroke: #decc93;
    stroke: ${e.noteBorderColor};
    fill: ${e.noteBkgColor};
  }

  .noteText, .noteText > tspan {
    fill: ${e.noteTextColor};
    stroke: none;
  }

  .activation0 {
    fill: ${e.activationBkgColor};
    stroke: ${e.activationBorderColor};
  }

  .activation1 {
    fill: ${e.activationBkgColor};
    stroke: ${e.activationBorderColor};
  }

  .activation2 {
    fill: ${e.activationBkgColor};
    stroke: ${e.activationBorderColor};
  }

  .actorPopupMenu {
    position: absolute;
  }

  .actorPopupMenuPanel {
    position: absolute;
    fill: ${e.actorBkg};
    box-shadow: 0px 8px 16px 0px rgba(0,0,0,0.2);
    filter: drop-shadow(3px 5px 2px rgb(0 0 0 / 0.4));
}
  .actor-man line {
    stroke: ${e.actorBorder};
    fill: ${e.actorBkg};
  }
  .actor-man circle, line {
    stroke: ${e.actorBorder};
    fill: ${e.actorBkg};
    stroke-width: 2px;
  }

`, "getStyles"), He = ze, Tt = 36, gt = "actor-top", xt = "actor-bottom", Ct = "actor-box", ut = "actor-man", Lt = /* @__PURE__ */ f(function(e, t) {
  return ve(e, t);
}, "drawRect"), Ue = /* @__PURE__ */ f(function(e, t, n, s, r) {
  if (t.links === void 0 || t.links === null || Object.keys(t.links).length === 0)
    return { height: 0, width: 0 };
  const i = t.links, c = t.actorCnt, h = t.rectData;
  var o = "none";
  r && (o = "block !important");
  const a = e.append("g");
  a.attr("id", "actor" + c + "_popup"), a.attr("class", "actorPopupMenu"), a.attr("display", o);
  var p = "";
  h.class !== void 0 && (p = " " + h.class);
  let g = h.width > n ? h.width : n;
  const x = a.append("rect");
  if (x.attr("class", "actorPopupMenuPanel" + p), x.attr("x", h.x), x.attr("y", h.height), x.attr("fill", h.fill), x.attr("stroke", h.stroke), x.attr("width", g), x.attr("height", h.height), x.attr("rx", h.rx), x.attr("ry", h.ry), i != null) {
    var y = 20;
    for (let k in i) {
      var m = a.append("a"), w = re.sanitizeUrl(i[k]);
      m.attr("xlink:href", w), m.attr("target", "_blank"), us(s)(
        k,
        m,
        h.x + 10,
        h.height + y,
        g,
        20,
        { class: "actor" },
        s
      ), y += 30;
    }
  }
  return x.attr("height", y), { height: h.height + y, width: g };
}, "drawPopup"), Ot = /* @__PURE__ */ f(function(e) {
  return "var pu = document.getElementById('" + e + "'); if (pu != null) { pu.style.display = pu.style.display == 'block' ? 'none' : 'block'; }";
}, "popupMenuToggle"), Dt = /* @__PURE__ */ f(async function(e, t, n = null) {
  let s = e.append("foreignObject");
  const r = await ne(t.text, Ht()), c = s.append("xhtml:div").attr("style", "width: fit-content;").attr("xmlns", "http://www.w3.org/1999/xhtml").html(r).node().getBoundingClientRect();
  if (s.attr("height", Math.round(c.height)).attr("width", Math.round(c.width)), t.class === "noteText") {
    const h = e.node().firstChild;
    h.setAttribute("height", c.height + 2 * t.textMargin);
    const o = h.getBBox();
    s.attr("x", Math.round(o.x + o.width / 2 - c.width / 2)).attr("y", Math.round(o.y + o.height / 2 - c.height / 2));
  } else if (n) {
    let { startx: h, stopx: o, starty: a } = n;
    if (h > o) {
      const p = h;
      h = o, o = p;
    }
    s.attr("x", Math.round(h + Math.abs(h - o) / 2 - c.width / 2)), t.class === "loopText" ? s.attr("y", Math.round(a)) : s.attr("y", Math.round(a - c.height));
  }
  return [s];
}, "drawKatex"), vt = /* @__PURE__ */ f(function(e, t) {
  let n = 0, s = 0;
  const r = t.text.split(I.lineBreakRegex), [i, c] = ie(t.fontSize);
  let h = [], o = 0, a = /* @__PURE__ */ f(() => t.y, "yfunc");
  if (t.valign !== void 0 && t.textMargin !== void 0 && t.textMargin > 0)
    switch (t.valign) {
      case "top":
      case "start":
        a = /* @__PURE__ */ f(() => Math.round(t.y + t.textMargin), "yfunc");
        break;
      case "middle":
      case "center":
        a = /* @__PURE__ */ f(() => Math.round(t.y + (n + s + t.textMargin) / 2), "yfunc");
        break;
      case "bottom":
      case "end":
        a = /* @__PURE__ */ f(() => Math.round(
          t.y + (n + s + 2 * t.textMargin) - t.textMargin
        ), "yfunc");
        break;
    }
  if (t.anchor !== void 0 && t.textMargin !== void 0 && t.width !== void 0)
    switch (t.anchor) {
      case "left":
      case "start":
        t.x = Math.round(t.x + t.textMargin), t.anchor = "start", t.dominantBaseline = "middle", t.alignmentBaseline = "middle";
        break;
      case "middle":
      case "center":
        t.x = Math.round(t.x + t.width / 2), t.anchor = "middle", t.dominantBaseline = "middle", t.alignmentBaseline = "middle";
        break;
      case "right":
      case "end":
        t.x = Math.round(t.x + t.width - t.textMargin), t.anchor = "end", t.dominantBaseline = "middle", t.alignmentBaseline = "middle";
        break;
    }
  for (let [p, g] of r.entries()) {
    t.textMargin !== void 0 && t.textMargin === 0 && i !== void 0 && (o = p * i);
    const x = e.append("text");
    x.attr("x", t.x), x.attr("y", a()), t.anchor !== void 0 && x.attr("text-anchor", t.anchor).attr("dominant-baseline", t.dominantBaseline).attr("alignment-baseline", t.alignmentBaseline), t.fontFamily !== void 0 && x.style("font-family", t.fontFamily), c !== void 0 && x.style("font-size", c), t.fontWeight !== void 0 && x.style("font-weight", t.fontWeight), t.fill !== void 0 && x.attr("fill", t.fill), t.class !== void 0 && x.attr("class", t.class), t.dy !== void 0 ? x.attr("dy", t.dy) : o !== 0 && x.attr("dy", o);
    const y = g || Ce;
    if (t.tspan) {
      const m = x.append("tspan");
      m.attr("x", t.x), t.fill !== void 0 && m.attr("fill", t.fill), m.text(y);
    } else
      x.text(y);
    t.valign !== void 0 && t.textMargin !== void 0 && t.textMargin > 0 && (s += (x._groups || x)[0][0].getBBox().height, n = s), h.push(x);
  }
  return h;
}, "drawText"), oe = /* @__PURE__ */ f(function(e, t) {
  function n(r, i, c, h, o) {
    return r + "," + i + " " + (r + c) + "," + i + " " + (r + c) + "," + (i + h - o) + " " + (r + c - o * 1.2) + "," + (i + h) + " " + r + "," + (i + h);
  }
  f(n, "genPoints");
  const s = e.append("polygon");
  return s.attr("points", n(t.x, t.y, t.width, t.height, 7)), s.attr("class", "labelBox"), t.y = t.y + t.height / 2, vt(e, t), s;
}, "drawLabel"), P = -1, ce = /* @__PURE__ */ f((e, t, n, s) => {
  e.select && n.forEach((r) => {
    const i = t.get(r), c = e.select("#actor" + i.actorCnt);
    !s.mirrorActors && i.stopy ? c.attr("y2", i.stopy + i.height / 2) : s.mirrorActors && c.attr("y2", i.stopy);
  });
}, "fixLifeLineHeights"), Ge = /* @__PURE__ */ f(function(e, t, n, s) {
  const r = s ? t.stopy : t.starty, i = t.x + t.width / 2, c = r + t.height, h = e.append("g").lower();
  var o = h;
  s || (P++, Object.keys(t.links || {}).length && !n.forceMenus && o.attr("onclick", Ot(`actor${P}_popup`)).attr("cursor", "pointer"), o.append("line").attr("id", "actor" + P).attr("x1", i).attr("y1", c).attr("x2", i).attr("y2", 2e3).attr("class", "actor-line 200").attr("stroke-width", "0.5px").attr("stroke", "#999").attr("name", t.name), o = h.append("g"), t.actorCnt = P, t.links != null && o.attr("id", "root-" + P));
  const a = ct();
  var p = "actor";
  t.properties?.class ? p = t.properties.class : a.fill = "#eaeaea", s ? p += ` ${xt}` : p += ` ${gt}`, a.x = t.x, a.y = r, a.width = t.width, a.height = t.height, a.class = p, a.rx = 3, a.ry = 3, a.name = t.name;
  const g = Lt(o, a);
  if (t.rectData = a, t.properties?.icon) {
    const y = t.properties.icon.trim();
    y.charAt(0) === "@" ? Jt(o, a.x + a.width - 20, a.y + 10, y.substr(1)) : Qt(o, a.x + a.width - 20, a.y + 10, y);
  }
  dt(n, z(t.description))(
    t.description,
    o,
    a.x,
    a.y,
    a.width,
    a.height,
    { class: `actor ${Ct}` },
    n
  );
  let x = t.height;
  if (g.node) {
    const y = g.node().getBBox();
    t.height = y.height, x = y.height;
  }
  return x;
}, "drawActorTypeParticipant"), Ke = /* @__PURE__ */ f(function(e, t, n, s) {
  const r = s ? t.stopy : t.starty, i = t.x + t.width / 2, c = r + t.height, h = e.append("g").lower();
  var o = h;
  s || (P++, Object.keys(t.links || {}).length && !n.forceMenus && o.attr("onclick", Ot(`actor${P}_popup`)).attr("cursor", "pointer"), o.append("line").attr("id", "actor" + P).attr("x1", i).attr("y1", c).attr("x2", i).attr("y2", 2e3).attr("class", "actor-line 200").attr("stroke-width", "0.5px").attr("stroke", "#999").attr("name", t.name), o = h.append("g"), t.actorCnt = P, t.links != null && o.attr("id", "root-" + P));
  const a = ct();
  var p = "actor";
  t.properties?.class ? p = t.properties.class : a.fill = "#eaeaea", s ? p += ` ${xt}` : p += ` ${gt}`, a.x = t.x, a.y = r, a.width = t.width, a.height = t.height, a.class = p, a.name = t.name;
  const g = 6, x = {
    ...a,
    x: a.x + -g,
    y: a.y + +g,
    class: "actor"
  }, y = Lt(o, a);
  if (Lt(o, x), t.rectData = a, t.properties?.icon) {
    const w = t.properties.icon.trim();
    w.charAt(0) === "@" ? Jt(o, a.x + a.width - 20, a.y + 10, w.substr(1)) : Qt(o, a.x + a.width - 20, a.y + 10, w);
  }
  dt(n, z(t.description))(
    t.description,
    o,
    a.x - g,
    a.y + g,
    a.width,
    a.height,
    { class: `actor ${Ct}` },
    n
  );
  let m = t.height;
  if (y.node) {
    const w = y.node().getBBox();
    t.height = w.height, m = w.height;
  }
  return m;
}, "drawActorTypeCollections"), Xe = /* @__PURE__ */ f(function(e, t, n, s) {
  const r = s ? t.stopy : t.starty, i = t.x + t.width / 2, c = r + t.height, h = e.append("g").lower();
  let o = h;
  s || (P++, Object.keys(t.links || {}).length && !n.forceMenus && o.attr("onclick", Ot(`actor${P}_popup`)).attr("cursor", "pointer"), o.append("line").attr("id", "actor" + P).attr("x1", i).attr("y1", c).attr("x2", i).attr("y2", 2e3).attr("class", "actor-line 200").attr("stroke-width", "0.5px").attr("stroke", "#999").attr("name", t.name), o = h.append("g"), t.actorCnt = P, t.links != null && o.attr("id", "root-" + P));
  const a = ct();
  let p = "actor";
  t.properties?.class ? p = t.properties.class : a.fill = "#eaeaea", s ? p += ` ${xt}` : p += ` ${gt}`, a.x = t.x, a.y = r, a.width = t.width, a.height = t.height, a.class = p, a.name = t.name;
  const g = a.height / 2, x = g / (2.5 + a.height / 50), y = o.append("g"), m = o.append("g");
  if (y.append("path").attr(
    "d",
    `M ${a.x},${a.y + g}
    a ${x},${g} 0 0 0 0,${a.height}
    h ${a.width - 2 * x}
    a ${x},${g} 0 0 0 0,-${a.height}
    Z
  `
  ).attr("class", p), m.append("path").attr(
    "d",
    `M ${a.x},${a.y + g}
      a ${x},${g} 0 0 0 0,${a.height}`
  ).attr("stroke", "#666").attr("stroke-width", "1px").attr("class", p), y.attr("transform", `translate(${x}, ${-(a.height / 2)})`), m.attr("transform", `translate(${a.width - x}, ${-a.height / 2})`), t.rectData = a, t.properties?.icon) {
    const N = t.properties.icon.trim(), S = a.x + a.width - 20, O = a.y + 10;
    N.charAt(0) === "@" ? Jt(o, S, O, N.substr(1)) : Qt(o, S, O, N);
  }
  dt(n, z(t.description))(
    t.description,
    o,
    a.x,
    a.y,
    a.width,
    a.height,
    { class: `actor ${Ct}` },
    n
  );
  let w = t.height;
  const k = y.select("path:last-child");
  if (k.node()) {
    const N = k.node().getBBox();
    t.height = N.height, w = N.height;
  }
  return w;
}, "drawActorTypeQueue"), Je = /* @__PURE__ */ f(function(e, t, n, s) {
  const r = s ? t.stopy : t.starty, i = t.x + t.width / 2, c = r + 75, h = e.append("g").lower();
  s || (P++, h.append("line").attr("id", "actor" + P).attr("x1", i).attr("y1", c).attr("x2", i).attr("y2", 2e3).attr("class", "actor-line 200").attr("stroke-width", "0.5px").attr("stroke", "#999").attr("name", t.name), t.actorCnt = P);
  const o = e.append("g");
  let a = ut;
  s ? a += ` ${xt}` : a += ` ${gt}`, o.attr("class", a), o.attr("name", t.name);
  const p = ct();
  p.x = t.x, p.y = r, p.fill = "#eaeaea", p.width = t.width, p.height = t.height, p.class = "actor";
  const g = t.x + t.width / 2, x = r + 30, y = 18;
  o.append("defs").append("marker").attr("id", "filled-head-control").attr("refX", 11).attr("refY", 5.8).attr("markerWidth", 20).attr("markerHeight", 28).attr("orient", "172.5").append("path").attr("d", "M 14.4 5.6 L 7.2 10.4 L 8.8 5.6 L 7.2 0.8 Z"), o.append("circle").attr("cx", g).attr("cy", x).attr("r", y).attr("fill", "#eaeaf7").attr("stroke", "#666").attr("stroke-width", 1.2), o.append("line").attr("marker-end", "url(#filled-head-control)").attr("transform", `translate(${g}, ${x - y})`);
  const m = o.node().getBBox();
  return t.height = m.height + 2 * (n?.sequence?.labelBoxHeight ?? 0), dt(n, z(t.description))(
    t.description,
    o,
    p.x,
    p.y + y + (s ? 5 : 10),
    p.width,
    p.height,
    { class: `actor ${ut}` },
    n
  ), t.height;
}, "drawActorTypeControl"), Qe = /* @__PURE__ */ f(function(e, t, n, s) {
  const r = s ? t.stopy : t.starty, i = t.x + t.width / 2, c = r + 75, h = e.append("g").lower(), o = e.append("g");
  let a = ut;
  s ? a += ` ${xt}` : a += ` ${gt}`, o.attr("class", a), o.attr("name", t.name);
  const p = ct();
  p.x = t.x, p.y = r, p.fill = "#eaeaea", p.width = t.width, p.height = t.height, p.class = "actor";
  const g = t.x + t.width / 2, x = r + (s ? 10 : 25), y = 18;
  o.append("circle").attr("cx", g).attr("cy", x).attr("r", y).attr("width", t.width).attr("height", t.height), o.append("line").attr("x1", g - y).attr("x2", g + y).attr("y1", x + y).attr("y2", x + y).attr("stroke", "#333").attr("stroke-width", 2);
  const m = o.node().getBBox();
  return t.height = m.height + (n?.sequence?.labelBoxHeight ?? 0), s || (P++, h.append("line").attr("id", "actor" + P).attr("x1", i).attr("y1", c).attr("x2", i).attr("y2", 2e3).attr("class", "actor-line 200").attr("stroke-width", "0.5px").attr("stroke", "#999").attr("name", t.name), t.actorCnt = P), dt(n, z(t.description))(
    t.description,
    o,
    p.x,
    p.y + (s ? (x - r + y - 5) / 2 : (x + y - r) / 2),
    p.width,
    p.height,
    { class: `actor ${ut}` },
    n
  ), s ? o.attr("transform", `translate(0, ${y / 2})`) : o.attr("transform", `translate(0, ${y / 2})`), t.height;
}, "drawActorTypeEntity"), Ze = /* @__PURE__ */ f(function(e, t, n, s) {
  const r = s ? t.stopy : t.starty, i = t.x + t.width / 2, c = r + t.height + 2 * n.boxTextMargin, h = e.append("g").lower();
  let o = h;
  s || (P++, Object.keys(t.links || {}).length && !n.forceMenus && o.attr("onclick", Ot(`actor${P}_popup`)).attr("cursor", "pointer"), o.append("line").attr("id", "actor" + P).attr("x1", i).attr("y1", c).attr("x2", i).attr("y2", 2e3).attr("class", "actor-line 200").attr("stroke-width", "0.5px").attr("stroke", "#999").attr("name", t.name), o = h.append("g"), t.actorCnt = P, t.links != null && o.attr("id", "root-" + P));
  const a = ct();
  let p = "actor";
  t.properties?.class ? p = t.properties.class : a.fill = "#eaeaea", s ? p += ` ${xt}` : p += ` ${gt}`, a.x = t.x, a.y = r, a.width = t.width, a.height = t.height, a.class = p, a.name = t.name, a.x = t.x, a.y = r;
  const g = a.width / 4, x = a.width / 4, y = g / 2, m = y / (2.5 + g / 50), w = o.append("g"), k = `
  M ${a.x},${a.y + m}
  a ${y},${m} 0 0 0 ${g},0
  a ${y},${m} 0 0 0 -${g},0
  l 0,${x - 2 * m}
  a ${y},${m} 0 0 0 ${g},0
  l 0,-${x - 2 * m}
`;
  w.append("path").attr("d", k).attr("fill", "#eaeaea").attr("stroke", "#000").attr("stroke-width", 1).attr("class", p), s ? w.attr("transform", `translate(${g * 1.5}, ${a.height / 4 - 2 * m})`) : w.attr("transform", `translate(${g * 1.5}, ${(a.height + m) / 4})`), t.rectData = a, dt(n, z(t.description))(
    t.description,
    o,
    a.x,
    a.y + (s ? (a.height + x) / 4 : (a.height + m) / 2),
    a.width,
    a.height,
    { class: `actor ${Ct}` },
    n
  );
  const N = w.select("path:last-child");
  if (N.node()) {
    const S = N.node().getBBox();
    t.height = S.height + (n.sequence.labelBoxHeight ?? 0);
  }
  return t.height;
}, "drawActorTypeDatabase"), $e = /* @__PURE__ */ f(function(e, t, n, s) {
  const r = s ? t.stopy : t.starty, i = t.x + t.width / 2, c = r + 80, h = 30, o = e.append("g").lower();
  s || (P++, o.append("line").attr("id", "actor" + P).attr("x1", i).attr("y1", c).attr("x2", i).attr("y2", 2e3).attr("class", "actor-line 200").attr("stroke-width", "0.5px").attr("stroke", "#999").attr("name", t.name), t.actorCnt = P);
  const a = e.append("g");
  let p = ut;
  s ? p += ` ${xt}` : p += ` ${gt}`, a.attr("class", p), a.attr("name", t.name);
  const g = ct();
  g.x = t.x, g.y = r, g.fill = "#eaeaea", g.width = t.width, g.height = t.height, g.class = "actor", a.append("line").attr("id", "actor-man-torso" + P).attr("x1", t.x + t.width / 2 - h * 2.5).attr("y1", r + 10).attr("x2", t.x + t.width / 2 - 15).attr("y2", r + 10), a.append("line").attr("id", "actor-man-arms" + P).attr("x1", t.x + t.width / 2 - h * 2.5).attr("y1", r + 0).attr("x2", t.x + t.width / 2 - h * 2.5).attr("y2", r + 20), a.append("circle").attr("cx", t.x + t.width / 2).attr("cy", r + 10).attr("r", h);
  const x = a.node().getBBox();
  return t.height = x.height + (n.sequence.labelBoxHeight ?? 0), dt(n, z(t.description))(
    t.description,
    a,
    g.x,
    g.y + (s ? h / 2 - 4 : h / 2 + 3),
    g.width,
    g.height,
    { class: `actor ${ut}` },
    n
  ), s ? a.attr("transform", `translate(0,${h / 2 + 7})`) : a.attr("transform", `translate(0,${h / 2 + 7})`), t.height;
}, "drawActorTypeBoundary"), je = /* @__PURE__ */ f(function(e, t, n, s) {
  const r = s ? t.stopy : t.starty, i = t.x + t.width / 2, c = r + 80, h = e.append("g").lower();
  s || (P++, h.append("line").attr("id", "actor" + P).attr("x1", i).attr("y1", c).attr("x2", i).attr("y2", 2e3).attr("class", "actor-line 200").attr("stroke-width", "0.5px").attr("stroke", "#999").attr("name", t.name), t.actorCnt = P);
  const o = e.append("g");
  let a = ut;
  s ? a += ` ${xt}` : a += ` ${gt}`, o.attr("class", a), o.attr("name", t.name);
  const p = ct();
  p.x = t.x, p.y = r, p.fill = "#eaeaea", p.width = t.width, p.height = t.height, p.class = "actor", p.rx = 3, p.ry = 3, o.append("line").attr("id", "actor-man-torso" + P).attr("x1", i).attr("y1", r + 25).attr("x2", i).attr("y2", r + 45), o.append("line").attr("id", "actor-man-arms" + P).attr("x1", i - Tt / 2).attr("y1", r + 33).attr("x2", i + Tt / 2).attr("y2", r + 33), o.append("line").attr("x1", i - Tt / 2).attr("y1", r + 60).attr("x2", i).attr("y2", r + 45), o.append("line").attr("x1", i).attr("y1", r + 45).attr("x2", i + Tt / 2 - 2).attr("y2", r + 60);
  const g = o.append("circle");
  g.attr("cx", t.x + t.width / 2), g.attr("cy", r + 10), g.attr("r", 15), g.attr("width", t.width), g.attr("height", t.height);
  const x = o.node().getBBox();
  return t.height = x.height, dt(n, z(t.description))(
    t.description,
    o,
    p.x,
    p.y + 35,
    p.width,
    p.height,
    { class: `actor ${ut}` },
    n
  ), t.height;
}, "drawActorTypeActor"), ts = /* @__PURE__ */ f(async function(e, t, n, s) {
  switch (t.type) {
    case "actor":
      return await je(e, t, n, s);
    case "participant":
      return await Ge(e, t, n, s);
    case "boundary":
      return await $e(e, t, n, s);
    case "control":
      return await Je(e, t, n, s);
    case "entity":
      return await Qe(e, t, n, s);
    case "database":
      return await Ze(e, t, n, s);
    case "collections":
      return await Ke(e, t, n, s);
    case "queue":
      return await Xe(e, t, n, s);
  }
}, "drawActor"), es = /* @__PURE__ */ f(function(e, t, n) {
  const r = e.append("g");
  le(r, t), t.name && dt(n)(
    t.name,
    r,
    t.x,
    t.y + n.boxTextMargin + (t.textMaxHeight || 0) / 2,
    t.width,
    0,
    { class: "text" },
    n
  ), r.lower();
}, "drawBox"), ss = /* @__PURE__ */ f(function(e) {
  return e.append("g");
}, "anchorElement"), as = /* @__PURE__ */ f(function(e, t, n, s, r) {
  const i = ct(), c = t.anchored;
  i.x = t.startx, i.y = t.starty, i.class = "activation" + r % 3, i.width = t.stopx - t.startx, i.height = n - t.starty, Lt(c, i);
}, "drawActivation"), rs = /* @__PURE__ */ f(async function(e, t, n, s) {
  const {
    boxMargin: r,
    boxTextMargin: i,
    labelBoxHeight: c,
    labelBoxWidth: h,
    messageFontFamily: o,
    messageFontSize: a,
    messageFontWeight: p
  } = s, g = e.append("g"), x = /* @__PURE__ */ f(function(w, k, N, S) {
    return g.append("line").attr("x1", w).attr("y1", k).attr("x2", N).attr("y2", S).attr("class", "loopLine");
  }, "drawLoopLine");
  x(t.startx, t.starty, t.stopx, t.starty), x(t.stopx, t.starty, t.stopx, t.stopy), x(t.startx, t.stopy, t.stopx, t.stopy), x(t.startx, t.starty, t.startx, t.stopy), t.sections !== void 0 && t.sections.forEach(function(w) {
    x(t.startx, w.y, t.stopx, w.y).style(
      "stroke-dasharray",
      "3, 3"
    );
  });
  let y = Xt();
  y.text = n, y.x = t.startx, y.y = t.starty, y.fontFamily = o, y.fontSize = a, y.fontWeight = p, y.anchor = "middle", y.valign = "middle", y.tspan = !1, y.width = h || 50, y.height = c || 20, y.textMargin = i, y.class = "labelText", oe(g, y), y = he(), y.text = t.title, y.x = t.startx + h / 2 + (t.stopx - t.startx) / 2, y.y = t.starty + r + i, y.anchor = "middle", y.valign = "middle", y.textMargin = i, y.class = "loopText", y.fontFamily = o, y.fontSize = a, y.fontWeight = p, y.wrap = !0;
  let m = z(y.text) ? await Dt(g, y, t) : vt(g, y);
  if (t.sectionTitles !== void 0) {
    for (const [w, k] of Object.entries(t.sectionTitles))
      if (k.message) {
        y.text = k.message, y.x = t.startx + (t.stopx - t.startx) / 2, y.y = t.sections[w].y + r + i, y.class = "loopText", y.anchor = "middle", y.valign = "middle", y.tspan = !1, y.fontFamily = o, y.fontSize = a, y.fontWeight = p, y.wrap = t.wrap, z(y.text) ? (t.starty = t.sections[w].y, await Dt(g, y, t)) : vt(g, y);
        let N = Math.round(
          m.map((S) => (S._groups || S)[0][0].getBBox().height).reduce((S, O) => S + O)
        );
        t.sections[w].height += N - (r + i);
      }
  }
  return t.height = Math.round(t.stopy - t.starty), g;
}, "drawLoop"), le = /* @__PURE__ */ f(function(e, t) {
  we(e, t);
}, "drawBackgroundRect"), is = /* @__PURE__ */ f(function(e) {
  e.append("defs").append("symbol").attr("id", "database").attr("fill-rule", "evenodd").attr("clip-rule", "evenodd").append("path").attr("transform", "scale(.5)").attr(
    "d",
    "M12.258.001l.256.004.255.005.253.008.251.01.249.012.247.015.246.016.242.019.241.02.239.023.236.024.233.027.231.028.229.031.225.032.223.034.22.036.217.038.214.04.211.041.208.043.205.045.201.046.198.048.194.05.191.051.187.053.183.054.18.056.175.057.172.059.168.06.163.061.16.063.155.064.15.066.074.033.073.033.071.034.07.034.069.035.068.035.067.035.066.035.064.036.064.036.062.036.06.036.06.037.058.037.058.037.055.038.055.038.053.038.052.038.051.039.05.039.048.039.047.039.045.04.044.04.043.04.041.04.04.041.039.041.037.041.036.041.034.041.033.042.032.042.03.042.029.042.027.042.026.043.024.043.023.043.021.043.02.043.018.044.017.043.015.044.013.044.012.044.011.045.009.044.007.045.006.045.004.045.002.045.001.045v17l-.001.045-.002.045-.004.045-.006.045-.007.045-.009.044-.011.045-.012.044-.013.044-.015.044-.017.043-.018.044-.02.043-.021.043-.023.043-.024.043-.026.043-.027.042-.029.042-.03.042-.032.042-.033.042-.034.041-.036.041-.037.041-.039.041-.04.041-.041.04-.043.04-.044.04-.045.04-.047.039-.048.039-.05.039-.051.039-.052.038-.053.038-.055.038-.055.038-.058.037-.058.037-.06.037-.06.036-.062.036-.064.036-.064.036-.066.035-.067.035-.068.035-.069.035-.07.034-.071.034-.073.033-.074.033-.15.066-.155.064-.16.063-.163.061-.168.06-.172.059-.175.057-.18.056-.183.054-.187.053-.191.051-.194.05-.198.048-.201.046-.205.045-.208.043-.211.041-.214.04-.217.038-.22.036-.223.034-.225.032-.229.031-.231.028-.233.027-.236.024-.239.023-.241.02-.242.019-.246.016-.247.015-.249.012-.251.01-.253.008-.255.005-.256.004-.258.001-.258-.001-.256-.004-.255-.005-.253-.008-.251-.01-.249-.012-.247-.015-.245-.016-.243-.019-.241-.02-.238-.023-.236-.024-.234-.027-.231-.028-.228-.031-.226-.032-.223-.034-.22-.036-.217-.038-.214-.04-.211-.041-.208-.043-.204-.045-.201-.046-.198-.048-.195-.05-.19-.051-.187-.053-.184-.054-.179-.056-.176-.057-.172-.059-.167-.06-.164-.061-.159-.063-.155-.064-.151-.066-.074-.033-.072-.033-.072-.034-.07-.034-.069-.035-.068-.035-.067-.035-.066-.035-.064-.036-.063-.036-.062-.036-.061-.036-.06-.037-.058-.037-.057-.037-.056-.038-.055-.038-.053-.038-.052-.038-.051-.039-.049-.039-.049-.039-.046-.039-.046-.04-.044-.04-.043-.04-.041-.04-.04-.041-.039-.041-.037-.041-.036-.041-.034-.041-.033-.042-.032-.042-.03-.042-.029-.042-.027-.042-.026-.043-.024-.043-.023-.043-.021-.043-.02-.043-.018-.044-.017-.043-.015-.044-.013-.044-.012-.044-.011-.045-.009-.044-.007-.045-.006-.045-.004-.045-.002-.045-.001-.045v-17l.001-.045.002-.045.004-.045.006-.045.007-.045.009-.044.011-.045.012-.044.013-.044.015-.044.017-.043.018-.044.02-.043.021-.043.023-.043.024-.043.026-.043.027-.042.029-.042.03-.042.032-.042.033-.042.034-.041.036-.041.037-.041.039-.041.04-.041.041-.04.043-.04.044-.04.046-.04.046-.039.049-.039.049-.039.051-.039.052-.038.053-.038.055-.038.056-.038.057-.037.058-.037.06-.037.061-.036.062-.036.063-.036.064-.036.066-.035.067-.035.068-.035.069-.035.07-.034.072-.034.072-.033.074-.033.151-.066.155-.064.159-.063.164-.061.167-.06.172-.059.176-.057.179-.056.184-.054.187-.053.19-.051.195-.05.198-.048.201-.046.204-.045.208-.043.211-.041.214-.04.217-.038.22-.036.223-.034.226-.032.228-.031.231-.028.234-.027.236-.024.238-.023.241-.02.243-.019.245-.016.247-.015.249-.012.251-.01.253-.008.255-.005.256-.004.258-.001.258.001zm-9.258 20.499v.01l.001.021.003.021.004.022.005.021.006.022.007.022.009.023.01.022.011.023.012.023.013.023.015.023.016.024.017.023.018.024.019.024.021.024.022.025.023.024.024.025.052.049.056.05.061.051.066.051.07.051.075.051.079.052.084.052.088.052.092.052.097.052.102.051.105.052.11.052.114.051.119.051.123.051.127.05.131.05.135.05.139.048.144.049.147.047.152.047.155.047.16.045.163.045.167.043.171.043.176.041.178.041.183.039.187.039.19.037.194.035.197.035.202.033.204.031.209.03.212.029.216.027.219.025.222.024.226.021.23.02.233.018.236.016.24.015.243.012.246.01.249.008.253.005.256.004.259.001.26-.001.257-.004.254-.005.25-.008.247-.011.244-.012.241-.014.237-.016.233-.018.231-.021.226-.021.224-.024.22-.026.216-.027.212-.028.21-.031.205-.031.202-.034.198-.034.194-.036.191-.037.187-.039.183-.04.179-.04.175-.042.172-.043.168-.044.163-.045.16-.046.155-.046.152-.047.148-.048.143-.049.139-.049.136-.05.131-.05.126-.05.123-.051.118-.052.114-.051.11-.052.106-.052.101-.052.096-.052.092-.052.088-.053.083-.051.079-.052.074-.052.07-.051.065-.051.06-.051.056-.05.051-.05.023-.024.023-.025.021-.024.02-.024.019-.024.018-.024.017-.024.015-.023.014-.024.013-.023.012-.023.01-.023.01-.022.008-.022.006-.022.006-.022.004-.022.004-.021.001-.021.001-.021v-4.127l-.077.055-.08.053-.083.054-.085.053-.087.052-.09.052-.093.051-.095.05-.097.05-.1.049-.102.049-.105.048-.106.047-.109.047-.111.046-.114.045-.115.045-.118.044-.12.043-.122.042-.124.042-.126.041-.128.04-.13.04-.132.038-.134.038-.135.037-.138.037-.139.035-.142.035-.143.034-.144.033-.147.032-.148.031-.15.03-.151.03-.153.029-.154.027-.156.027-.158.026-.159.025-.161.024-.162.023-.163.022-.165.021-.166.02-.167.019-.169.018-.169.017-.171.016-.173.015-.173.014-.175.013-.175.012-.177.011-.178.01-.179.008-.179.008-.181.006-.182.005-.182.004-.184.003-.184.002h-.37l-.184-.002-.184-.003-.182-.004-.182-.005-.181-.006-.179-.008-.179-.008-.178-.01-.176-.011-.176-.012-.175-.013-.173-.014-.172-.015-.171-.016-.17-.017-.169-.018-.167-.019-.166-.02-.165-.021-.163-.022-.162-.023-.161-.024-.159-.025-.157-.026-.156-.027-.155-.027-.153-.029-.151-.03-.15-.03-.148-.031-.146-.032-.145-.033-.143-.034-.141-.035-.14-.035-.137-.037-.136-.037-.134-.038-.132-.038-.13-.04-.128-.04-.126-.041-.124-.042-.122-.042-.12-.044-.117-.043-.116-.045-.113-.045-.112-.046-.109-.047-.106-.047-.105-.048-.102-.049-.1-.049-.097-.05-.095-.05-.093-.052-.09-.051-.087-.052-.085-.053-.083-.054-.08-.054-.077-.054v4.127zm0-5.654v.011l.001.021.003.021.004.021.005.022.006.022.007.022.009.022.01.022.011.023.012.023.013.023.015.024.016.023.017.024.018.024.019.024.021.024.022.024.023.025.024.024.052.05.056.05.061.05.066.051.07.051.075.052.079.051.084.052.088.052.092.052.097.052.102.052.105.052.11.051.114.051.119.052.123.05.127.051.131.05.135.049.139.049.144.048.147.048.152.047.155.046.16.045.163.045.167.044.171.042.176.042.178.04.183.04.187.038.19.037.194.036.197.034.202.033.204.032.209.03.212.028.216.027.219.025.222.024.226.022.23.02.233.018.236.016.24.014.243.012.246.01.249.008.253.006.256.003.259.001.26-.001.257-.003.254-.006.25-.008.247-.01.244-.012.241-.015.237-.016.233-.018.231-.02.226-.022.224-.024.22-.025.216-.027.212-.029.21-.03.205-.032.202-.033.198-.035.194-.036.191-.037.187-.039.183-.039.179-.041.175-.042.172-.043.168-.044.163-.045.16-.045.155-.047.152-.047.148-.048.143-.048.139-.05.136-.049.131-.05.126-.051.123-.051.118-.051.114-.052.11-.052.106-.052.101-.052.096-.052.092-.052.088-.052.083-.052.079-.052.074-.051.07-.052.065-.051.06-.05.056-.051.051-.049.023-.025.023-.024.021-.025.02-.024.019-.024.018-.024.017-.024.015-.023.014-.023.013-.024.012-.022.01-.023.01-.023.008-.022.006-.022.006-.022.004-.021.004-.022.001-.021.001-.021v-4.139l-.077.054-.08.054-.083.054-.085.052-.087.053-.09.051-.093.051-.095.051-.097.05-.1.049-.102.049-.105.048-.106.047-.109.047-.111.046-.114.045-.115.044-.118.044-.12.044-.122.042-.124.042-.126.041-.128.04-.13.039-.132.039-.134.038-.135.037-.138.036-.139.036-.142.035-.143.033-.144.033-.147.033-.148.031-.15.03-.151.03-.153.028-.154.028-.156.027-.158.026-.159.025-.161.024-.162.023-.163.022-.165.021-.166.02-.167.019-.169.018-.169.017-.171.016-.173.015-.173.014-.175.013-.175.012-.177.011-.178.009-.179.009-.179.007-.181.007-.182.005-.182.004-.184.003-.184.002h-.37l-.184-.002-.184-.003-.182-.004-.182-.005-.181-.007-.179-.007-.179-.009-.178-.009-.176-.011-.176-.012-.175-.013-.173-.014-.172-.015-.171-.016-.17-.017-.169-.018-.167-.019-.166-.02-.165-.021-.163-.022-.162-.023-.161-.024-.159-.025-.157-.026-.156-.027-.155-.028-.153-.028-.151-.03-.15-.03-.148-.031-.146-.033-.145-.033-.143-.033-.141-.035-.14-.036-.137-.036-.136-.037-.134-.038-.132-.039-.13-.039-.128-.04-.126-.041-.124-.042-.122-.043-.12-.043-.117-.044-.116-.044-.113-.046-.112-.046-.109-.046-.106-.047-.105-.048-.102-.049-.1-.049-.097-.05-.095-.051-.093-.051-.09-.051-.087-.053-.085-.052-.083-.054-.08-.054-.077-.054v4.139zm0-5.666v.011l.001.02.003.022.004.021.005.022.006.021.007.022.009.023.01.022.011.023.012.023.013.023.015.023.016.024.017.024.018.023.019.024.021.025.022.024.023.024.024.025.052.05.056.05.061.05.066.051.07.051.075.052.079.051.084.052.088.052.092.052.097.052.102.052.105.051.11.052.114.051.119.051.123.051.127.05.131.05.135.05.139.049.144.048.147.048.152.047.155.046.16.045.163.045.167.043.171.043.176.042.178.04.183.04.187.038.19.037.194.036.197.034.202.033.204.032.209.03.212.028.216.027.219.025.222.024.226.021.23.02.233.018.236.017.24.014.243.012.246.01.249.008.253.006.256.003.259.001.26-.001.257-.003.254-.006.25-.008.247-.01.244-.013.241-.014.237-.016.233-.018.231-.02.226-.022.224-.024.22-.025.216-.027.212-.029.21-.03.205-.032.202-.033.198-.035.194-.036.191-.037.187-.039.183-.039.179-.041.175-.042.172-.043.168-.044.163-.045.16-.045.155-.047.152-.047.148-.048.143-.049.139-.049.136-.049.131-.051.126-.05.123-.051.118-.052.114-.051.11-.052.106-.052.101-.052.096-.052.092-.052.088-.052.083-.052.079-.052.074-.052.07-.051.065-.051.06-.051.056-.05.051-.049.023-.025.023-.025.021-.024.02-.024.019-.024.018-.024.017-.024.015-.023.014-.024.013-.023.012-.023.01-.022.01-.023.008-.022.006-.022.006-.022.004-.022.004-.021.001-.021.001-.021v-4.153l-.077.054-.08.054-.083.053-.085.053-.087.053-.09.051-.093.051-.095.051-.097.05-.1.049-.102.048-.105.048-.106.048-.109.046-.111.046-.114.046-.115.044-.118.044-.12.043-.122.043-.124.042-.126.041-.128.04-.13.039-.132.039-.134.038-.135.037-.138.036-.139.036-.142.034-.143.034-.144.033-.147.032-.148.032-.15.03-.151.03-.153.028-.154.028-.156.027-.158.026-.159.024-.161.024-.162.023-.163.023-.165.021-.166.02-.167.019-.169.018-.169.017-.171.016-.173.015-.173.014-.175.013-.175.012-.177.01-.178.01-.179.009-.179.007-.181.006-.182.006-.182.004-.184.003-.184.001-.185.001-.185-.001-.184-.001-.184-.003-.182-.004-.182-.006-.181-.006-.179-.007-.179-.009-.178-.01-.176-.01-.176-.012-.175-.013-.173-.014-.172-.015-.171-.016-.17-.017-.169-.018-.167-.019-.166-.02-.165-.021-.163-.023-.162-.023-.161-.024-.159-.024-.157-.026-.156-.027-.155-.028-.153-.028-.151-.03-.15-.03-.148-.032-.146-.032-.145-.033-.143-.034-.141-.034-.14-.036-.137-.036-.136-.037-.134-.038-.132-.039-.13-.039-.128-.041-.126-.041-.124-.041-.122-.043-.12-.043-.117-.044-.116-.044-.113-.046-.112-.046-.109-.046-.106-.048-.105-.048-.102-.048-.1-.05-.097-.049-.095-.051-.093-.051-.09-.052-.087-.052-.085-.053-.083-.053-.08-.054-.077-.054v4.153zm8.74-8.179l-.257.004-.254.005-.25.008-.247.011-.244.012-.241.014-.237.016-.233.018-.231.021-.226.022-.224.023-.22.026-.216.027-.212.028-.21.031-.205.032-.202.033-.198.034-.194.036-.191.038-.187.038-.183.04-.179.041-.175.042-.172.043-.168.043-.163.045-.16.046-.155.046-.152.048-.148.048-.143.048-.139.049-.136.05-.131.05-.126.051-.123.051-.118.051-.114.052-.11.052-.106.052-.101.052-.096.052-.092.052-.088.052-.083.052-.079.052-.074.051-.07.052-.065.051-.06.05-.056.05-.051.05-.023.025-.023.024-.021.024-.02.025-.019.024-.018.024-.017.023-.015.024-.014.023-.013.023-.012.023-.01.023-.01.022-.008.022-.006.023-.006.021-.004.022-.004.021-.001.021-.001.021.001.021.001.021.004.021.004.022.006.021.006.023.008.022.01.022.01.023.012.023.013.023.014.023.015.024.017.023.018.024.019.024.02.025.021.024.023.024.023.025.051.05.056.05.06.05.065.051.07.052.074.051.079.052.083.052.088.052.092.052.096.052.101.052.106.052.11.052.114.052.118.051.123.051.126.051.131.05.136.05.139.049.143.048.148.048.152.048.155.046.16.046.163.045.168.043.172.043.175.042.179.041.183.04.187.038.191.038.194.036.198.034.202.033.205.032.21.031.212.028.216.027.22.026.224.023.226.022.231.021.233.018.237.016.241.014.244.012.247.011.25.008.254.005.257.004.26.001.26-.001.257-.004.254-.005.25-.008.247-.011.244-.012.241-.014.237-.016.233-.018.231-.021.226-.022.224-.023.22-.026.216-.027.212-.028.21-.031.205-.032.202-.033.198-.034.194-.036.191-.038.187-.038.183-.04.179-.041.175-.042.172-.043.168-.043.163-.045.16-.046.155-.046.152-.048.148-.048.143-.048.139-.049.136-.05.131-.05.126-.051.123-.051.118-.051.114-.052.11-.052.106-.052.101-.052.096-.052.092-.052.088-.052.083-.052.079-.052.074-.051.07-.052.065-.051.06-.05.056-.05.051-.05.023-.025.023-.024.021-.024.02-.025.019-.024.018-.024.017-.023.015-.024.014-.023.013-.023.012-.023.01-.023.01-.022.008-.022.006-.023.006-.021.004-.022.004-.021.001-.021.001-.021-.001-.021-.001-.021-.004-.021-.004-.022-.006-.021-.006-.023-.008-.022-.01-.022-.01-.023-.012-.023-.013-.023-.014-.023-.015-.024-.017-.023-.018-.024-.019-.024-.02-.025-.021-.024-.023-.024-.023-.025-.051-.05-.056-.05-.06-.05-.065-.051-.07-.052-.074-.051-.079-.052-.083-.052-.088-.052-.092-.052-.096-.052-.101-.052-.106-.052-.11-.052-.114-.052-.118-.051-.123-.051-.126-.051-.131-.05-.136-.05-.139-.049-.143-.048-.148-.048-.152-.048-.155-.046-.16-.046-.163-.045-.168-.043-.172-.043-.175-.042-.179-.041-.183-.04-.187-.038-.191-.038-.194-.036-.198-.034-.202-.033-.205-.032-.21-.031-.212-.028-.216-.027-.22-.026-.224-.023-.226-.022-.231-.021-.233-.018-.237-.016-.241-.014-.244-.012-.247-.011-.25-.008-.254-.005-.257-.004-.26-.001-.26.001z"
  );
}, "insertDatabaseIcon"), ns = /* @__PURE__ */ f(function(e) {
  e.append("defs").append("symbol").attr("id", "computer").attr("width", "24").attr("height", "24").append("path").attr("transform", "scale(.5)").attr(
    "d",
    "M2 2v13h20v-13h-20zm18 11h-16v-9h16v9zm-10.228 6l.466-1h3.524l.467 1h-4.457zm14.228 3h-24l2-6h2.104l-1.33 4h18.45l-1.297-4h2.073l2 6zm-5-10h-14v-7h14v7z"
  );
}, "insertComputerIcon"), os = /* @__PURE__ */ f(function(e) {
  e.append("defs").append("symbol").attr("id", "clock").attr("width", "24").attr("height", "24").append("path").attr("transform", "scale(.5)").attr(
    "d",
    "M12 2c5.514 0 10 4.486 10 10s-4.486 10-10 10-10-4.486-10-10 4.486-10 10-10zm0-2c-6.627 0-12 5.373-12 12s5.373 12 12 12 12-5.373 12-12-5.373-12-12-12zm5.848 12.459c.202.038.202.333.001.372-1.907.361-6.045 1.111-6.547 1.111-.719 0-1.301-.582-1.301-1.301 0-.512.77-5.447 1.125-7.445.034-.192.312-.181.343.014l.985 6.238 5.394 1.011z"
  );
}, "insertClockIcon"), cs = /* @__PURE__ */ f(function(e) {
  e.append("defs").append("marker").attr("id", "arrowhead").attr("refX", 7.9).attr("refY", 5).attr("markerUnits", "userSpaceOnUse").attr("markerWidth", 12).attr("markerHeight", 12).attr("orient", "auto-start-reverse").append("path").attr("d", "M -1 0 L 10 5 L 0 10 z");
}, "insertArrowHead"), ls = /* @__PURE__ */ f(function(e) {
  e.append("defs").append("marker").attr("id", "filled-head").attr("refX", 15.5).attr("refY", 7).attr("markerWidth", 20).attr("markerHeight", 28).attr("orient", "auto").append("path").attr("d", "M 18,7 L9,13 L14,7 L9,1 Z");
}, "insertArrowFilledHead"), hs = /* @__PURE__ */ f(function(e) {
  e.append("defs").append("marker").attr("id", "sequencenumber").attr("refX", 15).attr("refY", 15).attr("markerWidth", 60).attr("markerHeight", 40).attr("orient", "auto").append("circle").attr("cx", 15).attr("cy", 15).attr("r", 6);
}, "insertSequenceNumber"), ds = /* @__PURE__ */ f(function(e) {
  e.append("defs").append("marker").attr("id", "crosshead").attr("markerWidth", 15).attr("markerHeight", 8).attr("orient", "auto").attr("refX", 4).attr("refY", 4.5).append("path").attr("fill", "none").attr("stroke", "#000000").style("stroke-dasharray", "0, 0").attr("stroke-width", "1pt").attr("d", "M 1,2 L 6,7 M 6,2 L 1,7");
}, "insertArrowCrossHead"), he = /* @__PURE__ */ f(function() {
  return {
    x: 0,
    y: 0,
    fill: void 0,
    anchor: void 0,
    style: "#666",
    width: void 0,
    height: void 0,
    textMargin: 0,
    rx: 0,
    ry: 0,
    tspan: !0,
    valign: void 0
  };
}, "getTextObj"), ps = /* @__PURE__ */ f(function() {
  return {
    x: 0,
    y: 0,
    fill: "#EDF2AE",
    stroke: "#666",
    width: 100,
    anchor: "start",
    height: 100,
    rx: 0,
    ry: 0
  };
}, "getNoteRect"), dt = /* @__PURE__ */ (function() {
  function e(i, c, h, o, a, p, g) {
    const x = c.append("text").attr("x", h + a / 2).attr("y", o + p / 2 + 5).style("text-anchor", "middle").text(i);
    r(x, g);
  }
  f(e, "byText");
  function t(i, c, h, o, a, p, g, x) {
    const { actorFontSize: y, actorFontFamily: m, actorFontWeight: w } = x, [k, N] = ie(y), S = i.split(I.lineBreakRegex);
    for (let O = 0; O < S.length; O++) {
      const B = O * k - k * (S.length - 1) / 2, q = c.append("text").attr("x", h + a / 2).attr("y", o).style("text-anchor", "middle").style("font-size", N).style("font-weight", w).style("font-family", m);
      q.append("tspan").attr("x", h + a / 2).attr("dy", B).text(S[O]), q.attr("y", o + p / 2).attr("dominant-baseline", "central").attr("alignment-baseline", "central"), r(q, g);
    }
  }
  f(t, "byTspan");
  function n(i, c, h, o, a, p, g, x) {
    const y = c.append("switch"), w = y.append("foreignObject").attr("x", h).attr("y", o).attr("width", a).attr("height", p).append("xhtml:div").style("display", "table").style("height", "100%").style("width", "100%");
    w.append("div").style("display", "table-cell").style("text-align", "center").style("vertical-align", "middle").text(i), t(i, y, h, o, a, p, g, x), r(w, g);
  }
  f(n, "byFo");
  async function s(i, c, h, o, a, p, g, x) {
    const y = await _t(i, Ht()), m = c.append("switch"), k = m.append("foreignObject").attr("x", h + a / 2 - y.width / 2).attr("y", o + p / 2 - y.height / 2).attr("width", y.width).attr("height", y.height).append("xhtml:div").style("height", "100%").style("width", "100%");
    k.append("div").style("text-align", "center").style("vertical-align", "middle").html(await ne(i, Ht())), t(i, m, h, o, a, p, g, x), r(k, g);
  }
  f(s, "byKatex");
  function r(i, c) {
    for (const h in c)
      c.hasOwnProperty(h) && i.attr(h, c[h]);
  }
  return f(r, "_setTextAttrs"), function(i, c = !1) {
    return c ? s : i.textPlacement === "fo" ? n : i.textPlacement === "old" ? e : t;
  };
})(), us = /* @__PURE__ */ (function() {
  function e(r, i, c, h, o, a, p) {
    const g = i.append("text").attr("x", c).attr("y", h).style("text-anchor", "start").text(r);
    s(g, p);
  }
  f(e, "byText");
  function t(r, i, c, h, o, a, p, g) {
    const { actorFontSize: x, actorFontFamily: y, actorFontWeight: m } = g, w = r.split(I.lineBreakRegex);
    for (let k = 0; k < w.length; k++) {
      const N = k * x - x * (w.length - 1) / 2, S = i.append("text").attr("x", c).attr("y", h).style("text-anchor", "start").style("font-size", x).style("font-weight", m).style("font-family", y);
      S.append("tspan").attr("x", c).attr("dy", N).text(w[k]), S.attr("y", h + a / 2).attr("dominant-baseline", "central").attr("alignment-baseline", "central"), s(S, p);
    }
  }
  f(t, "byTspan");
  function n(r, i, c, h, o, a, p, g) {
    const x = i.append("switch"), m = x.append("foreignObject").attr("x", c).attr("y", h).attr("width", o).attr("height", a).append("xhtml:div").style("display", "table").style("height", "100%").style("width", "100%");
    m.append("div").style("display", "table-cell").style("text-align", "center").style("vertical-align", "middle").text(r), t(r, x, c, h, o, a, p, g), s(m, p);
  }
  f(n, "byFo");
  function s(r, i) {
    for (const c in i)
      i.hasOwnProperty(c) && r.attr(c, i[c]);
  }
  return f(s, "_setTextAttrs"), function(r) {
    return r.textPlacement === "fo" ? n : r.textPlacement === "old" ? e : t;
  };
})(), V = {
  drawRect: Lt,
  drawText: vt,
  drawLabel: oe,
  drawActor: ts,
  drawBox: es,
  drawPopup: Ue,
  anchorElement: ss,
  drawActivation: as,
  drawLoop: rs,
  drawBackgroundRect: le,
  insertArrowHead: cs,
  insertArrowFilledHead: ls,
  insertSequenceNumber: hs,
  insertArrowCrossHead: ds,
  insertDatabaseIcon: is,
  insertComputerIcon: ns,
  insertClockIcon: os,
  getTextObj: he,
  getNoteRect: ps,
  fixLifeLineHeights: ce,
  sanitizeUrl: re.sanitizeUrl
}, l = {}, T = {
  data: {
    startx: void 0,
    stopx: void 0,
    starty: void 0,
    stopy: void 0
  },
  verticalPos: 0,
  sequenceItems: [],
  activations: [],
  models: {
    getHeight: /* @__PURE__ */ f(function() {
      return Math.max.apply(
        null,
        this.actors.length === 0 ? [0] : this.actors.map((e) => e.height || 0)
      ) + (this.loops.length === 0 ? 0 : this.loops.map((e) => e.height || 0).reduce((e, t) => e + t)) + (this.messages.length === 0 ? 0 : this.messages.map((e) => e.height || 0).reduce((e, t) => e + t)) + (this.notes.length === 0 ? 0 : this.notes.map((e) => e.height || 0).reduce((e, t) => e + t));
    }, "getHeight"),
    clear: /* @__PURE__ */ f(function() {
      this.actors = [], this.boxes = [], this.loops = [], this.messages = [], this.notes = [];
    }, "clear"),
    addBox: /* @__PURE__ */ f(function(e) {
      this.boxes.push(e);
    }, "addBox"),
    addActor: /* @__PURE__ */ f(function(e) {
      this.actors.push(e);
    }, "addActor"),
    addLoop: /* @__PURE__ */ f(function(e) {
      this.loops.push(e);
    }, "addLoop"),
    addMessage: /* @__PURE__ */ f(function(e) {
      this.messages.push(e);
    }, "addMessage"),
    addNote: /* @__PURE__ */ f(function(e) {
      this.notes.push(e);
    }, "addNote"),
    lastActor: /* @__PURE__ */ f(function() {
      return this.actors[this.actors.length - 1];
    }, "lastActor"),
    lastLoop: /* @__PURE__ */ f(function() {
      return this.loops[this.loops.length - 1];
    }, "lastLoop"),
    lastMessage: /* @__PURE__ */ f(function() {
      return this.messages[this.messages.length - 1];
    }, "lastMessage"),
    lastNote: /* @__PURE__ */ f(function() {
      return this.notes[this.notes.length - 1];
    }, "lastNote"),
    actors: [],
    boxes: [],
    loops: [],
    messages: [],
    notes: []
  },
  init: /* @__PURE__ */ f(function() {
    this.sequenceItems = [], this.activations = [], this.models.clear(), this.data = {
      startx: void 0,
      stopx: void 0,
      starty: void 0,
      stopy: void 0
    }, this.verticalPos = 0, ue(st());
  }, "init"),
  updateVal: /* @__PURE__ */ f(function(e, t, n, s) {
    e[t] === void 0 ? e[t] = n : e[t] = s(n, e[t]);
  }, "updateVal"),
  updateBounds: /* @__PURE__ */ f(function(e, t, n, s) {
    const r = this;
    let i = 0;
    function c(h) {
      return /* @__PURE__ */ f(function(a) {
        i++;
        const p = r.sequenceItems.length - i + 1;
        r.updateVal(a, "starty", t - p * l.boxMargin, Math.min), r.updateVal(a, "stopy", s + p * l.boxMargin, Math.max), r.updateVal(T.data, "startx", e - p * l.boxMargin, Math.min), r.updateVal(T.data, "stopx", n + p * l.boxMargin, Math.max), h !== "activation" && (r.updateVal(a, "startx", e - p * l.boxMargin, Math.min), r.updateVal(a, "stopx", n + p * l.boxMargin, Math.max), r.updateVal(T.data, "starty", t - p * l.boxMargin, Math.min), r.updateVal(T.data, "stopy", s + p * l.boxMargin, Math.max));
      }, "updateItemBounds");
    }
    f(c, "updateFn"), this.sequenceItems.forEach(c()), this.activations.forEach(c("activation"));
  }, "updateBounds"),
  insert: /* @__PURE__ */ f(function(e, t, n, s) {
    const r = I.getMin(e, n), i = I.getMax(e, n), c = I.getMin(t, s), h = I.getMax(t, s);
    this.updateVal(T.data, "startx", r, Math.min), this.updateVal(T.data, "starty", c, Math.min), this.updateVal(T.data, "stopx", i, Math.max), this.updateVal(T.data, "stopy", h, Math.max), this.updateBounds(r, c, i, h);
  }, "insert"),
  newActivation: /* @__PURE__ */ f(function(e, t, n) {
    const s = n.get(e.from), r = Bt(e.from).length || 0, i = s.x + s.width / 2 + (r - 1) * l.activationWidth / 2;
    this.activations.push({
      startx: i,
      starty: this.verticalPos + 2,
      stopx: i + l.activationWidth,
      stopy: void 0,
      actor: e.from,
      anchored: V.anchorElement(t)
    });
  }, "newActivation"),
  endActivation: /* @__PURE__ */ f(function(e) {
    const t = this.activations.map(function(n) {
      return n.actor;
    }).lastIndexOf(e.from);
    return this.activations.splice(t, 1)[0];
  }, "endActivation"),
  createLoop: /* @__PURE__ */ f(function(e = { message: void 0, wrap: !1, width: void 0 }, t) {
    return {
      startx: void 0,
      starty: this.verticalPos,
      stopx: void 0,
      stopy: void 0,
      title: e.message,
      wrap: e.wrap,
      width: e.width,
      height: 0,
      fill: t
    };
  }, "createLoop"),
  newLoop: /* @__PURE__ */ f(function(e = { message: void 0, wrap: !1, width: void 0 }, t) {
    this.sequenceItems.push(this.createLoop(e, t));
  }, "newLoop"),
  endLoop: /* @__PURE__ */ f(function() {
    return this.sequenceItems.pop();
  }, "endLoop"),
  isLoopOverlap: /* @__PURE__ */ f(function() {
    return this.sequenceItems.length ? this.sequenceItems[this.sequenceItems.length - 1].overlap : !1;
  }, "isLoopOverlap"),
  addSectionToLoop: /* @__PURE__ */ f(function(e) {
    const t = this.sequenceItems.pop();
    t.sections = t.sections || [], t.sectionTitles = t.sectionTitles || [], t.sections.push({ y: T.getVerticalPos(), height: 0 }), t.sectionTitles.push(e), this.sequenceItems.push(t);
  }, "addSectionToLoop"),
  saveVerticalPos: /* @__PURE__ */ f(function() {
    this.isLoopOverlap() && (this.savedVerticalPos = this.verticalPos);
  }, "saveVerticalPos"),
  resetVerticalPos: /* @__PURE__ */ f(function() {
    this.isLoopOverlap() && (this.verticalPos = this.savedVerticalPos);
  }, "resetVerticalPos"),
  bumpVerticalPos: /* @__PURE__ */ f(function(e) {
    this.verticalPos = this.verticalPos + e, this.data.stopy = I.getMax(this.data.stopy, this.verticalPos);
  }, "bumpVerticalPos"),
  getVerticalPos: /* @__PURE__ */ f(function() {
    return this.verticalPos;
  }, "getVerticalPos"),
  getBounds: /* @__PURE__ */ f(function() {
    return { bounds: this.data, models: this.models };
  }, "getBounds")
}, gs = /* @__PURE__ */ f(async function(e, t) {
  T.bumpVerticalPos(l.boxMargin), t.height = l.boxMargin, t.starty = T.getVerticalPos();
  const n = ct();
  n.x = t.startx, n.y = t.starty, n.width = t.width || l.width, n.class = "note";
  const s = e.append("g"), r = V.drawRect(s, n), i = Xt();
  i.x = t.startx, i.y = t.starty, i.width = n.width, i.dy = "1em", i.text = t.message, i.class = "noteText", i.fontFamily = l.noteFontFamily, i.fontSize = l.noteFontSize, i.fontWeight = l.noteFontWeight, i.anchor = l.noteAlign, i.textMargin = l.noteMargin, i.valign = "center";
  const c = z(i.text) ? await Dt(s, i) : vt(s, i), h = Math.round(
    c.map((o) => (o._groups || o)[0][0].getBBox().height).reduce((o, a) => o + a)
  );
  r.attr("height", h + 2 * l.noteMargin), t.height += h + 2 * l.noteMargin, T.bumpVerticalPos(h + 2 * l.noteMargin), t.stopy = t.starty + h + 2 * l.noteMargin, t.stopx = t.startx + n.width, T.insert(t.startx, t.starty, t.stopx, t.stopy), T.models.addNote(t);
}, "drawNote"), Et = /* @__PURE__ */ f((e) => ({
  fontFamily: e.messageFontFamily,
  fontSize: e.messageFontSize,
  fontWeight: e.messageFontWeight
}), "messageFont"), mt = /* @__PURE__ */ f((e) => ({
  fontFamily: e.noteFontFamily,
  fontSize: e.noteFontSize,
  fontWeight: e.noteFontWeight
}), "noteFont"), Gt = /* @__PURE__ */ f((e) => ({
  fontFamily: e.actorFontFamily,
  fontSize: e.actorFontSize,
  fontWeight: e.actorFontWeight
}), "actorFont");
async function de(e, t) {
  T.bumpVerticalPos(10);
  const { startx: n, stopx: s, message: r } = t, i = I.splitBreaks(r).length, c = z(r), h = c ? await _t(r, st()) : W.calculateTextDimensions(r, Et(l));
  if (!c) {
    const g = h.height / i;
    t.height += g, T.bumpVerticalPos(g);
  }
  let o, a = h.height - 10;
  const p = h.width;
  if (n === s) {
    o = T.getVerticalPos() + a, l.rightAngles || (a += l.boxMargin, o = T.getVerticalPos() + a), a += 30;
    const g = I.getMax(p / 2, l.width / 2);
    T.insert(
      n - g,
      T.getVerticalPos() - 10 + a,
      s + g,
      T.getVerticalPos() + 30 + a
    );
  } else
    a += l.boxMargin, o = T.getVerticalPos() + a, T.insert(n, o - 10, s, o);
  return T.bumpVerticalPos(a), t.height += a, t.stopy = t.starty + t.height, T.insert(t.fromBounds, t.starty, t.toBounds, t.stopy), o;
}
f(de, "boundMessage");
var xs = /* @__PURE__ */ f(async function(e, t, n, s) {
  const { startx: r, stopx: i, starty: c, message: h, type: o, sequenceIndex: a, sequenceVisible: p } = t, g = W.calculateTextDimensions(h, Et(l)), x = Xt();
  x.x = r, x.y = c + 10, x.width = i - r, x.class = "messageText", x.dy = "1em", x.text = h, x.fontFamily = l.messageFontFamily, x.fontSize = l.messageFontSize, x.fontWeight = l.messageFontWeight, x.anchor = l.messageAlign, x.valign = "center", x.textMargin = l.wrapPadding, x.tspan = !1, z(x.text) ? await Dt(e, x, { startx: r, stopx: i, starty: n }) : vt(e, x);
  const y = g.width;
  let m;
  r === i ? l.rightAngles ? m = e.append("path").attr(
    "d",
    `M  ${r},${n} H ${r + I.getMax(l.width / 2, y / 2)} V ${n + 25} H ${r}`
  ) : m = e.append("path").attr(
    "d",
    "M " + r + "," + n + " C " + (r + 60) + "," + (n - 10) + " " + (r + 60) + "," + (n + 30) + " " + r + "," + (n + 20)
  ) : (m = e.append("line"), m.attr("x1", r), m.attr("y1", n), m.attr("x2", i), m.attr("y2", n)), o === s.db.LINETYPE.DOTTED || o === s.db.LINETYPE.DOTTED_CROSS || o === s.db.LINETYPE.DOTTED_POINT || o === s.db.LINETYPE.DOTTED_OPEN || o === s.db.LINETYPE.BIDIRECTIONAL_DOTTED ? (m.style("stroke-dasharray", "3, 3"), m.attr("class", "messageLine1")) : m.attr("class", "messageLine0");
  let w = "";
  l.arrowMarkerAbsolute && (w = Oe(!0)), m.attr("stroke-width", 2), m.attr("stroke", "none"), m.style("fill", "none"), (o === s.db.LINETYPE.SOLID || o === s.db.LINETYPE.DOTTED) && m.attr("marker-end", "url(" + w + "#arrowhead)"), (o === s.db.LINETYPE.BIDIRECTIONAL_SOLID || o === s.db.LINETYPE.BIDIRECTIONAL_DOTTED) && (m.attr("marker-start", "url(" + w + "#arrowhead)"), m.attr("marker-end", "url(" + w + "#arrowhead)")), (o === s.db.LINETYPE.SOLID_POINT || o === s.db.LINETYPE.DOTTED_POINT) && m.attr("marker-end", "url(" + w + "#filled-head)"), (o === s.db.LINETYPE.SOLID_CROSS || o === s.db.LINETYPE.DOTTED_CROSS) && m.attr("marker-end", "url(" + w + "#crosshead)"), (p || l.showSequenceNumbers) && ((o === s.db.LINETYPE.BIDIRECTIONAL_SOLID || o === s.db.LINETYPE.BIDIRECTIONAL_DOTTED) && (r < i ? m.attr("x1", r + 12) : m.attr("x1", r + 6)), e.append("line").attr("x1", r).attr("y1", n).attr("x2", r).attr("y2", n).attr("stroke-width", 0).attr("marker-start", "url(" + w + "#sequencenumber)"), e.append("text").attr("x", r).attr("y", n + 4).attr("font-family", "sans-serif").attr("font-size", "12px").attr("text-anchor", "middle").attr("class", "sequenceNumber").text(a));
}, "drawMessage"), fs = /* @__PURE__ */ f(function(e, t, n, s, r, i, c) {
  let h = 0, o = 0, a, p = 0;
  for (const g of s) {
    const x = t.get(g), y = x.box;
    a && a != y && (c || T.models.addBox(a), o += l.boxMargin + a.margin), y && y != a && (c || (y.x = h + o, y.y = r), o += y.margin), x.width = x.width || l.width, x.height = I.getMax(x.height || l.height, l.height), x.margin = x.margin || l.actorMargin, p = I.getMax(p, x.height), n.get(x.name) && (o += x.width / 2), x.x = h + o, x.starty = T.getVerticalPos(), T.insert(x.x, r, x.x + x.width, x.height), h += x.width + o, x.box && (x.box.width = h + y.margin - x.box.x), o = x.margin, a = x.box, T.models.addActor(x);
  }
  a && !c && T.models.addBox(a), T.bumpVerticalPos(p);
}, "addActorRenderingData"), Kt = /* @__PURE__ */ f(async function(e, t, n, s) {
  if (s) {
    let r = 0;
    T.bumpVerticalPos(l.boxMargin * 2);
    for (const i of n) {
      const c = t.get(i);
      c.stopy || (c.stopy = T.getVerticalPos());
      const h = await V.drawActor(e, c, l, !0);
      r = I.getMax(r, h);
    }
    T.bumpVerticalPos(r + l.boxMargin);
  } else
    for (const r of n) {
      const i = t.get(r);
      await V.drawActor(e, i, l, !1);
    }
}, "drawActors"), pe = /* @__PURE__ */ f(function(e, t, n, s) {
  let r = 0, i = 0;
  for (const c of n) {
    const h = t.get(c), o = Ts(h), a = V.drawPopup(
      e,
      h,
      o,
      l,
      l.forceMenus,
      s
    );
    a.height > r && (r = a.height), a.width + h.x > i && (i = a.width + h.x);
  }
  return { maxHeight: r, maxWidth: i };
}, "drawActorsPopup"), ue = /* @__PURE__ */ f(function(e) {
  _e(l, e), e.fontFamily && (l.actorFontFamily = l.noteFontFamily = l.messageFontFamily = e.fontFamily), e.fontSize && (l.actorFontSize = l.noteFontSize = l.messageFontSize = e.fontSize), e.fontWeight && (l.actorFontWeight = l.noteFontWeight = l.messageFontWeight = e.fontWeight);
}, "setConf"), Bt = /* @__PURE__ */ f(function(e) {
  return T.activations.filter(function(t) {
    return t.actor === e;
  });
}, "actorActivations"), ae = /* @__PURE__ */ f(function(e, t) {
  const n = t.get(e), s = Bt(e), r = s.reduce(
    function(c, h) {
      return I.getMin(c, h.startx);
    },
    n.x + n.width / 2 - 1
  ), i = s.reduce(
    function(c, h) {
      return I.getMax(c, h.stopx);
    },
    n.x + n.width / 2 + 1
  );
  return [r, i];
}, "activationBounds");
function nt(e, t, n, s, r) {
  T.bumpVerticalPos(n);
  let i = s;
  if (t.id && t.message && e[t.id]) {
    const c = e[t.id].width, h = Et(l);
    t.message = W.wrapLabel(`[${t.message}]`, c - 2 * l.wrapPadding, h), t.width = c, t.wrap = !0;
    const o = W.calculateTextDimensions(t.message, h), a = I.getMax(o.height, l.labelBoxHeight);
    i = s + a, Q.debug(`${a} - ${t.message}`);
  }
  r(t), T.bumpVerticalPos(i);
}
f(nt, "adjustLoopHeightForWrap");
function ge(e, t, n, s, r, i, c) {
  function h(p, g) {
    p.x < r.get(e.from).x ? (T.insert(
      t.stopx - g,
      t.starty,
      t.startx,
      t.stopy + p.height / 2 + l.noteMargin
    ), t.stopx = t.stopx + g) : (T.insert(
      t.startx,
      t.starty,
      t.stopx + g,
      t.stopy + p.height / 2 + l.noteMargin
    ), t.stopx = t.stopx - g);
  }
  f(h, "receiverAdjustment");
  function o(p, g) {
    p.x < r.get(e.to).x ? (T.insert(
      t.startx - g,
      t.starty,
      t.stopx,
      t.stopy + p.height / 2 + l.noteMargin
    ), t.startx = t.startx + g) : (T.insert(
      t.stopx,
      t.starty,
      t.startx + g,
      t.stopy + p.height / 2 + l.noteMargin
    ), t.startx = t.startx - g);
  }
  f(o, "senderAdjustment");
  const a = [
    Rt.ACTOR,
    Rt.CONTROL,
    Rt.ENTITY,
    Rt.DATABASE
  ];
  if (i.get(e.to) == s) {
    const p = r.get(e.to), g = a.includes(p.type) ? Tt / 2 + 3 : p.width / 2 + 3;
    h(p, g), p.starty = n - p.height / 2, T.bumpVerticalPos(p.height / 2);
  } else if (c.get(e.from) == s) {
    const p = r.get(e.from);
    if (l.mirrorActors) {
      const g = a.includes(p.type) ? Tt / 2 : p.width / 2;
      o(p, g);
    }
    p.stopy = n - p.height / 2, T.bumpVerticalPos(p.height / 2);
  } else if (c.get(e.to) == s) {
    const p = r.get(e.to);
    if (l.mirrorActors) {
      const g = a.includes(p.type) ? Tt / 2 + 3 : p.width / 2 + 3;
      h(p, g);
    }
    p.stopy = n - p.height / 2, T.bumpVerticalPos(p.height / 2);
  }
}
f(ge, "adjustCreatedDestroyedData");
var ys = /* @__PURE__ */ f(async function(e, t, n, s) {
  const { securityLevel: r, sequence: i } = st();
  l = i;
  let c;
  r === "sandbox" && (c = St("#i" + t));
  const h = r === "sandbox" ? St(c.nodes()[0].contentDocument.body) : St("body"), o = r === "sandbox" ? c.nodes()[0].contentDocument : document;
  T.init(), Q.debug(s.db);
  const a = r === "sandbox" ? h.select(`[id="${t}"]`) : St(`[id="${t}"]`), p = s.db.getActors(), g = s.db.getCreatedActors(), x = s.db.getDestroyedActors(), y = s.db.getBoxes();
  let m = s.db.getActorKeys();
  const w = s.db.getMessages(), k = s.db.getDiagramTitle(), N = s.db.hasAtLeastOneBox(), S = s.db.hasAtLeastOneBoxWithTitle(), O = await xe(p, w, s);
  if (l.height = await fe(p, O, y), V.insertComputerIcon(a), V.insertDatabaseIcon(a), V.insertClockIcon(a), N && (T.bumpVerticalPos(l.boxMargin), S && T.bumpVerticalPos(y[0].textMaxHeight)), l.hideUnusedParticipants === !0) {
    const E = /* @__PURE__ */ new Set();
    w.forEach((_) => {
      E.add(_.from), E.add(_.to);
    }), m = m.filter((_) => E.has(_));
  }
  fs(a, p, g, m, 0, w, !1);
  const B = await ms(w, p, O, s);
  V.insertArrowHead(a), V.insertArrowCrossHead(a), V.insertArrowFilledHead(a), V.insertSequenceNumber(a);
  function q(E, _) {
    const X = T.endActivation(E);
    X.starty + 18 > _ && (X.starty = _ - 6, _ += 12), V.drawActivation(
      a,
      X,
      _,
      l,
      Bt(E.from).length
    ), T.insert(X.startx, _ - 10, X.stopx, _);
  }
  f(q, "activeEnd");
  let H = 1, Z = 1;
  const at = [], U = [];
  let G = 0;
  for (const E of w) {
    let _, X, tt;
    switch (E.type) {
      case s.db.LINETYPE.NOTE:
        T.resetVerticalPos(), X = E.noteModel, await gs(a, X);
        break;
      case s.db.LINETYPE.ACTIVE_START:
        T.newActivation(E, a, p);
        break;
      case s.db.LINETYPE.ACTIVE_END:
        q(E, T.getVerticalPos());
        break;
      case s.db.LINETYPE.LOOP_START:
        nt(
          B,
          E,
          l.boxMargin,
          l.boxMargin + l.boxTextMargin,
          (M) => T.newLoop(M)
        );
        break;
      case s.db.LINETYPE.LOOP_END:
        _ = T.endLoop(), await V.drawLoop(a, _, "loop", l), T.bumpVerticalPos(_.stopy - T.getVerticalPos()), T.models.addLoop(_);
        break;
      case s.db.LINETYPE.RECT_START:
        nt(
          B,
          E,
          l.boxMargin,
          l.boxMargin,
          (M) => T.newLoop(void 0, M.message)
        );
        break;
      case s.db.LINETYPE.RECT_END:
        _ = T.endLoop(), U.push(_), T.models.addLoop(_), T.bumpVerticalPos(_.stopy - T.getVerticalPos());
        break;
      case s.db.LINETYPE.OPT_START:
        nt(
          B,
          E,
          l.boxMargin,
          l.boxMargin + l.boxTextMargin,
          (M) => T.newLoop(M)
        );
        break;
      case s.db.LINETYPE.OPT_END:
        _ = T.endLoop(), await V.drawLoop(a, _, "opt", l), T.bumpVerticalPos(_.stopy - T.getVerticalPos()), T.models.addLoop(_);
        break;
      case s.db.LINETYPE.ALT_START:
        nt(
          B,
          E,
          l.boxMargin,
          l.boxMargin + l.boxTextMargin,
          (M) => T.newLoop(M)
        );
        break;
      case s.db.LINETYPE.ALT_ELSE:
        nt(
          B,
          E,
          l.boxMargin + l.boxTextMargin,
          l.boxMargin,
          (M) => T.addSectionToLoop(M)
        );
        break;
      case s.db.LINETYPE.ALT_END:
        _ = T.endLoop(), await V.drawLoop(a, _, "alt", l), T.bumpVerticalPos(_.stopy - T.getVerticalPos()), T.models.addLoop(_);
        break;
      case s.db.LINETYPE.PAR_START:
      case s.db.LINETYPE.PAR_OVER_START:
        nt(
          B,
          E,
          l.boxMargin,
          l.boxMargin + l.boxTextMargin,
          (M) => T.newLoop(M)
        ), T.saveVerticalPos();
        break;
      case s.db.LINETYPE.PAR_AND:
        nt(
          B,
          E,
          l.boxMargin + l.boxTextMargin,
          l.boxMargin,
          (M) => T.addSectionToLoop(M)
        );
        break;
      case s.db.LINETYPE.PAR_END:
        _ = T.endLoop(), await V.drawLoop(a, _, "par", l), T.bumpVerticalPos(_.stopy - T.getVerticalPos()), T.models.addLoop(_);
        break;
      case s.db.LINETYPE.AUTONUMBER:
        H = E.message.start || H, Z = E.message.step || Z, E.message.visible ? s.db.enableSequenceNumbers() : s.db.disableSequenceNumbers();
        break;
      case s.db.LINETYPE.CRITICAL_START:
        nt(
          B,
          E,
          l.boxMargin,
          l.boxMargin + l.boxTextMargin,
          (M) => T.newLoop(M)
        );
        break;
      case s.db.LINETYPE.CRITICAL_OPTION:
        nt(
          B,
          E,
          l.boxMargin + l.boxTextMargin,
          l.boxMargin,
          (M) => T.addSectionToLoop(M)
        );
        break;
      case s.db.LINETYPE.CRITICAL_END:
        _ = T.endLoop(), await V.drawLoop(a, _, "critical", l), T.bumpVerticalPos(_.stopy - T.getVerticalPos()), T.models.addLoop(_);
        break;
      case s.db.LINETYPE.BREAK_START:
        nt(
          B,
          E,
          l.boxMargin,
          l.boxMargin + l.boxTextMargin,
          (M) => T.newLoop(M)
        );
        break;
      case s.db.LINETYPE.BREAK_END:
        _ = T.endLoop(), await V.drawLoop(a, _, "break", l), T.bumpVerticalPos(_.stopy - T.getVerticalPos()), T.models.addLoop(_);
        break;
      default:
        try {
          tt = E.msgModel, tt.starty = T.getVerticalPos(), tt.sequenceIndex = H, tt.sequenceVisible = s.db.showSequenceNumbers();
          const M = await de(a, tt);
          ge(
            E,
            tt,
            M,
            G,
            p,
            g,
            x
          ), at.push({ messageModel: tt, lineStartY: M }), T.models.addMessage(tt);
        } catch (M) {
          Q.error("error while drawing message", M);
        }
    }
    [
      s.db.LINETYPE.SOLID_OPEN,
      s.db.LINETYPE.DOTTED_OPEN,
      s.db.LINETYPE.SOLID,
      s.db.LINETYPE.DOTTED,
      s.db.LINETYPE.SOLID_CROSS,
      s.db.LINETYPE.DOTTED_CROSS,
      s.db.LINETYPE.SOLID_POINT,
      s.db.LINETYPE.DOTTED_POINT,
      s.db.LINETYPE.BIDIRECTIONAL_SOLID,
      s.db.LINETYPE.BIDIRECTIONAL_DOTTED
    ].includes(E.type) && (H = H + Z), G++;
  }
  Q.debug("createdActors", g), Q.debug("destroyedActors", x), await Kt(a, p, m, !1);
  for (const E of at)
    await xs(a, E.messageModel, E.lineStartY, s);
  l.mirrorActors && await Kt(a, p, m, !0), U.forEach((E) => V.drawBackgroundRect(a, E)), ce(a, p, m, l);
  for (const E of T.models.boxes) {
    E.height = T.getVerticalPos() - E.y, T.insert(E.x, E.y, E.x + E.width, E.height);
    const _ = l.boxMargin * 2;
    E.startx = E.x - _, E.starty = E.y - _ * 0.25, E.stopx = E.startx + E.width + 2 * _, E.stopy = E.starty + E.height + _ * 0.75, E.stroke = "rgb(0,0,0, 0.5)", V.drawBox(a, E, l);
  }
  N && T.bumpVerticalPos(l.boxMargin);
  const F = pe(a, p, m, o), { bounds: D } = T.getBounds();
  D.startx === void 0 && (D.startx = 0), D.starty === void 0 && (D.starty = 0), D.stopx === void 0 && (D.stopx = 0), D.stopy === void 0 && (D.stopy = 0);
  let $ = D.stopy - D.starty;
  $ < F.maxHeight && ($ = F.maxHeight);
  let K = $ + 2 * l.diagramMarginY;
  l.mirrorActors && (K = K - l.boxMargin + l.bottomMarginAdj);
  let j = D.stopx - D.startx;
  j < F.maxWidth && (j = F.maxWidth);
  const rt = j + 2 * l.diagramMarginX;
  k && a.append("text").text(k).attr("x", (D.stopx - D.startx) / 2 - 2 * l.diagramMarginX).attr("y", -25), Le(a, K, rt, l.useMaxWidth);
  const R = k ? 40 : 0;
  a.attr(
    "viewBox",
    D.startx - l.diagramMarginX + " -" + (l.diagramMarginY + R) + " " + rt + " " + (K + R)
  ), Q.debug("models:", T.models);
}, "draw");
async function xe(e, t, n) {
  const s = {};
  for (const r of t)
    if (e.get(r.to) && e.get(r.from)) {
      const i = e.get(r.to);
      if (r.placement === n.db.PLACEMENT.LEFTOF && !i.prevActor || r.placement === n.db.PLACEMENT.RIGHTOF && !i.nextActor)
        continue;
      const c = r.placement !== void 0, h = !c, o = c ? mt(l) : Et(l), a = r.wrap ? W.wrapLabel(r.message, l.width - 2 * l.wrapPadding, o) : r.message, g = (z(a) ? await _t(r.message, st()) : W.calculateTextDimensions(a, o)).width + 2 * l.wrapPadding;
      h && r.from === i.nextActor ? s[r.to] = I.getMax(
        s[r.to] || 0,
        g
      ) : h && r.from === i.prevActor ? s[r.from] = I.getMax(
        s[r.from] || 0,
        g
      ) : h && r.from === r.to ? (s[r.from] = I.getMax(
        s[r.from] || 0,
        g / 2
      ), s[r.to] = I.getMax(
        s[r.to] || 0,
        g / 2
      )) : r.placement === n.db.PLACEMENT.RIGHTOF ? s[r.from] = I.getMax(
        s[r.from] || 0,
        g
      ) : r.placement === n.db.PLACEMENT.LEFTOF ? s[i.prevActor] = I.getMax(
        s[i.prevActor] || 0,
        g
      ) : r.placement === n.db.PLACEMENT.OVER && (i.prevActor && (s[i.prevActor] = I.getMax(
        s[i.prevActor] || 0,
        g / 2
      )), i.nextActor && (s[r.from] = I.getMax(
        s[r.from] || 0,
        g / 2
      )));
    }
  return Q.debug("maxMessageWidthPerActor:", s), s;
}
f(xe, "getMaxMessageWidthPerActor");
var Ts = /* @__PURE__ */ f(function(e) {
  let t = 0;
  const n = Gt(l);
  for (const s in e.links) {
    const i = W.calculateTextDimensions(s, n).width + 2 * l.wrapPadding + 2 * l.boxMargin;
    t < i && (t = i);
  }
  return t;
}, "getRequiredPopupWidth");
async function fe(e, t, n) {
  let s = 0;
  for (const i of e.keys()) {
    const c = e.get(i);
    c.wrap && (c.description = W.wrapLabel(
      c.description,
      l.width - 2 * l.wrapPadding,
      Gt(l)
    ));
    const h = z(c.description) ? await _t(c.description, st()) : W.calculateTextDimensions(c.description, Gt(l));
    c.width = c.wrap ? l.width : I.getMax(l.width, h.width + 2 * l.wrapPadding), c.height = c.wrap ? I.getMax(h.height, l.height) : l.height, s = I.getMax(s, c.height);
  }
  for (const i in t) {
    const c = e.get(i);
    if (!c)
      continue;
    const h = e.get(c.nextActor);
    if (!h) {
      const g = t[i] + l.actorMargin - c.width / 2;
      c.margin = I.getMax(g, l.actorMargin);
      continue;
    }
    const a = t[i] + l.actorMargin - c.width / 2 - h.width / 2;
    c.margin = I.getMax(a, l.actorMargin);
  }
  let r = 0;
  return n.forEach((i) => {
    const c = Et(l);
    let h = i.actorKeys.reduce((g, x) => g += e.get(x).width + (e.get(x).margin || 0), 0);
    const o = l.boxMargin * 8;
    h += o, h -= 2 * l.boxTextMargin, i.wrap && (i.name = W.wrapLabel(i.name, h - 2 * l.wrapPadding, c));
    const a = W.calculateTextDimensions(i.name, c);
    r = I.getMax(a.height, r);
    const p = I.getMax(h, a.width + 2 * l.wrapPadding);
    if (i.margin = l.boxTextMargin, h < p) {
      const g = (p - h) / 2;
      i.margin += g;
    }
  }), n.forEach((i) => i.textMaxHeight = r), I.getMax(s, l.height);
}
f(fe, "calculateActorMargins");
var Es = /* @__PURE__ */ f(async function(e, t, n) {
  const s = t.get(e.from), r = t.get(e.to), i = s.x, c = r.x, h = e.wrap && e.message;
  let o = z(e.message) ? await _t(e.message, st()) : W.calculateTextDimensions(
    h ? W.wrapLabel(e.message, l.width, mt(l)) : e.message,
    mt(l)
  );
  const a = {
    width: h ? l.width : I.getMax(l.width, o.width + 2 * l.noteMargin),
    height: 0,
    startx: s.x,
    stopx: 0,
    starty: 0,
    stopy: 0,
    message: e.message
  };
  return e.placement === n.db.PLACEMENT.RIGHTOF ? (a.width = h ? I.getMax(l.width, o.width) : I.getMax(
    s.width / 2 + r.width / 2,
    o.width + 2 * l.noteMargin
  ), a.startx = i + (s.width + l.actorMargin) / 2) : e.placement === n.db.PLACEMENT.LEFTOF ? (a.width = h ? I.getMax(l.width, o.width + 2 * l.noteMargin) : I.getMax(
    s.width / 2 + r.width / 2,
    o.width + 2 * l.noteMargin
  ), a.startx = i - a.width + (s.width - l.actorMargin) / 2) : e.to === e.from ? (o = W.calculateTextDimensions(
    h ? W.wrapLabel(e.message, I.getMax(l.width, s.width), mt(l)) : e.message,
    mt(l)
  ), a.width = h ? I.getMax(l.width, s.width) : I.getMax(s.width, l.width, o.width + 2 * l.noteMargin), a.startx = i + (s.width - a.width) / 2) : (a.width = Math.abs(i + s.width / 2 - (c + r.width / 2)) + l.actorMargin, a.startx = i < c ? i + s.width / 2 - l.actorMargin / 2 : c + r.width / 2 - l.actorMargin / 2), h && (a.message = W.wrapLabel(
    e.message,
    a.width - 2 * l.wrapPadding,
    mt(l)
  )), Q.debug(
    `NM:[${a.startx},${a.stopx},${a.starty},${a.stopy}:${a.width},${a.height}=${e.message}]`
  ), a;
}, "buildNoteModel"), bs = /* @__PURE__ */ f(function(e, t, n) {
  if (![
    n.db.LINETYPE.SOLID_OPEN,
    n.db.LINETYPE.DOTTED_OPEN,
    n.db.LINETYPE.SOLID,
    n.db.LINETYPE.DOTTED,
    n.db.LINETYPE.SOLID_CROSS,
    n.db.LINETYPE.DOTTED_CROSS,
    n.db.LINETYPE.SOLID_POINT,
    n.db.LINETYPE.DOTTED_POINT,
    n.db.LINETYPE.BIDIRECTIONAL_SOLID,
    n.db.LINETYPE.BIDIRECTIONAL_DOTTED
  ].includes(e.type))
    return {};
  const [s, r] = ae(e.from, t), [i, c] = ae(e.to, t), h = s <= i;
  let o = h ? r : s, a = h ? i : c;
  const p = Math.abs(i - c) > 2, g = /* @__PURE__ */ f((w) => h ? -w : w, "adjustValue");
  e.from === e.to ? a = o : (e.activate && !p && (a += g(l.activationWidth / 2 - 1)), [n.db.LINETYPE.SOLID_OPEN, n.db.LINETYPE.DOTTED_OPEN].includes(e.type) || (a += g(3)), [n.db.LINETYPE.BIDIRECTIONAL_SOLID, n.db.LINETYPE.BIDIRECTIONAL_DOTTED].includes(
    e.type
  ) && (o -= g(3)));
  const x = [s, r, i, c], y = Math.abs(o - a);
  e.wrap && e.message && (e.message = W.wrapLabel(
    e.message,
    I.getMax(y + 2 * l.wrapPadding, l.width),
    Et(l)
  ));
  const m = W.calculateTextDimensions(e.message, Et(l));
  return {
    width: I.getMax(
      e.wrap ? 0 : m.width + 2 * l.wrapPadding,
      y + 2 * l.wrapPadding,
      l.width
    ),
    height: 0,
    startx: o,
    stopx: a,
    starty: 0,
    stopy: 0,
    message: e.message,
    type: e.type,
    wrap: e.wrap,
    fromBounds: Math.min.apply(null, x),
    toBounds: Math.max.apply(null, x)
  };
}, "buildMessageModel"), ms = /* @__PURE__ */ f(async function(e, t, n, s) {
  const r = {}, i = [];
  let c, h, o;
  for (const a of e) {
    switch (a.type) {
      case s.db.LINETYPE.LOOP_START:
      case s.db.LINETYPE.ALT_START:
      case s.db.LINETYPE.OPT_START:
      case s.db.LINETYPE.PAR_START:
      case s.db.LINETYPE.PAR_OVER_START:
      case s.db.LINETYPE.CRITICAL_START:
      case s.db.LINETYPE.BREAK_START:
        i.push({
          id: a.id,
          msg: a.message,
          from: Number.MAX_SAFE_INTEGER,
          to: Number.MIN_SAFE_INTEGER,
          width: 0
        });
        break;
      case s.db.LINETYPE.ALT_ELSE:
      case s.db.LINETYPE.PAR_AND:
      case s.db.LINETYPE.CRITICAL_OPTION:
        a.message && (c = i.pop(), r[c.id] = c, r[a.id] = c, i.push(c));
        break;
      case s.db.LINETYPE.LOOP_END:
      case s.db.LINETYPE.ALT_END:
      case s.db.LINETYPE.OPT_END:
      case s.db.LINETYPE.PAR_END:
      case s.db.LINETYPE.CRITICAL_END:
      case s.db.LINETYPE.BREAK_END:
        c = i.pop(), r[c.id] = c;
        break;
      case s.db.LINETYPE.ACTIVE_START:
        {
          const g = t.get(a.from ? a.from : a.to.actor), x = Bt(a.from ? a.from : a.to.actor).length, y = g.x + g.width / 2 + (x - 1) * l.activationWidth / 2, m = {
            startx: y,
            stopx: y + l.activationWidth,
            actor: a.from,
            enabled: !0
          };
          T.activations.push(m);
        }
        break;
      case s.db.LINETYPE.ACTIVE_END:
        {
          const g = T.activations.map((x) => x.actor).lastIndexOf(a.from);
          T.activations.splice(g, 1).splice(0, 1);
        }
        break;
    }
    a.placement !== void 0 ? (h = await Es(a, t, s), a.noteModel = h, i.forEach((g) => {
      c = g, c.from = I.getMin(c.from, h.startx), c.to = I.getMax(c.to, h.startx + h.width), c.width = I.getMax(c.width, Math.abs(c.from - c.to)) - l.labelBoxWidth;
    })) : (o = bs(a, t, s), a.msgModel = o, o.startx && o.stopx && i.length > 0 && i.forEach((g) => {
      if (c = g, o.startx === o.stopx) {
        const x = t.get(a.from), y = t.get(a.to);
        c.from = I.getMin(
          x.x - o.width / 2,
          x.x - x.width / 2,
          c.from
        ), c.to = I.getMax(
          y.x + o.width / 2,
          y.x + x.width / 2,
          c.to
        ), c.width = I.getMax(c.width, Math.abs(c.to - c.from)) - l.labelBoxWidth;
      } else
        c.from = I.getMin(o.startx, c.from), c.to = I.getMax(o.stopx, c.to), c.width = I.getMax(c.width, o.width) - l.labelBoxWidth;
    }));
  }
  return T.activations = [], Q.debug("Loop type widths:", r), r;
}, "calculateLoopBounds"), ws = {
  bounds: T,
  drawActors: Kt,
  drawActorsPopup: pe,
  setConf: ue,
  draw: ys
}, _s = {
  parser: Ve,
  get db() {
    return new qe();
  },
  renderer: ws,
  styles: He,
  init: /* @__PURE__ */ f((e) => {
    e.sequence || (e.sequence = {}), e.wrap && (e.sequence.wrap = e.wrap, Ie({ sequence: { wrap: e.wrap } }));
  }, "init")
};
export {
  _s as diagram
};
